<?php
/**
 * Global Constants
 */

define('REALITE_THEME_DIR', get_template_directory());
define('REALITE_THEME_URI', get_template_directory_uri());
define('REALITE_THEME_STYLESHEET', get_stylesheet_uri());
define('REALITE_THEME_PLACEHOLDER', get_template_directory_uri() . '/assets/images/placeholder.png');
define('REALITE_THEME_NAME', 'realite');
define('REALITE_THEME_VERSION', wp_get_theme()->get('Version'));

/**
 * Content Width
 */
!isset($content_width) ? $content_width = 1920 : '';

/**
 * Text Domain
 */
load_theme_textdomain('realite', REALITE_THEME_DIR . '/languages');

require get_parent_theme_file_path ( '/inc/lib/nav-menu/main-menu.php' );

// Action to call init
add_action('after_setup_theme', 'realite_init');

/**
 * Realite Init
 */
function realite_init() {
	# Theme Support
	add_theme_support('title-tag');
	add_theme_support('widgets');
	add_theme_support('automatic-feed-links');
	add_theme_support('post-thumbnails');
	add_theme_support('featured-image');

	// WooCommerce Theme Support
	if (class_exists('WooCommerce')) {
		add_theme_support('woocommerce');
		add_theme_support('wc-product-gallery-zoom');
		add_theme_support('wc-product-gallery-lightbox');
		add_theme_support('wc-product-gallery-slider');
	}

	# HTML5 Galleries
	add_theme_support( 'html5', array( 'gallery', 'caption', 'style', 'script' ) );

	// Include custom files
	include(REALITE_THEME_DIR . '/inc/grada-functions.php');
	include(REALITE_THEME_DIR . '/inc/grada-custom-style.php');
	include_once(REALITE_THEME_DIR . '/inc/lib/class-tgm-plugin-activation.php');
	include_once(REALITE_THEME_DIR . '/inc/acf-fields.php');
	get_theme_mod('custom_fields_panel', '2') == '2' ? define('ACF_LITE' , true) : '';

	// Theme actions within init function
	add_action('tgmpa_register', 'realite_plugins');
	add_action('wp_enqueue_scripts', 'realite_register_styles');
	add_action('wp_enqueue_scripts', 'realite_register_scripts');
	add_action('admin_enqueue_scripts', 'realite_admin_scripts');
	add_action('widgets_init', 'realite_register_sidebars');

	// Theme Filters
	if (class_exists('Kirki')){
		add_filter('kirki_telemetry', '__return_false');
	}

	// Register Menus
	register_nav_menus(
		array(
			'main-menu' => esc_html__('Main Menu', 'realite')
		)
	);
}

/**
 * TGMPA Include Plugins
 */
function realite_plugins() {

	$plugins = array(
		array(
			'name'      => esc_html__('Advanced Custom Fields', 'realite'),
			'slug'      => 'advanced-custom-fields',
			'required'  => true
		),
		array(
			'name'      => esc_html__('Elementor', 'realite'),
			'slug'      => 'elementor',
			'required'  => true
		),
		array(
			'name'      => esc_html__('Revolution Slider', 'realite'),
			'slug'      => 'revslider',
			'source'    => get_template_directory() . '/inc/plugins/revslider.zip',
			'required'  => false
		),
		array(
			'name'        => esc_html__('Realite Plugin', 'realite'),
			'slug'        => 'realite-plugin',
			'source'    	=> get_template_directory() . '/inc/plugins/realite-plugin.zip',
			'required'    => true
		),
		array(
			'name'      => esc_html__('WooCommerce', 'realite'),
			'slug'      => 'woocommerce',
			'required'  => false
		),
		array(
			'name'       => esc_html__('One Click Demo Import', 'realite'),
			'slug'       => 'one-click-demo-import',
			'required'   => false
		),
		array(
			'name'       => esc_html__('Contact Form 7', 'realite'),
			'slug'       => 'contact-form-7',
			'required'   => false
		)
	);

	$config = array(
		'id'           => 'tgmpa',
		'default_path' => '',
		'menu'         => 'tgmpa-install-plugins',
		'parent_slug'  => 'themes.php',
		'capability'   => 'edit_theme_options',
		'has_notices'  => true,
		'dismissable'  => true,
		'dismiss_msg'  => '',
		'is_automatic' => false,
		'message'      => ''
	);
	tgmpa($plugins, $config);
}

/**
 * Realite CSS
 */
function realite_register_styles() {
	wp_enqueue_style( 'realite-main-style', REALITE_THEME_URI . '/assets/css/realite.css', false,REALITE_THEME_VERSION, null );
	wp_enqueue_style('magnific-popup', REALITE_THEME_URI . '/assets/css/magnific-popup.css', false, REALITE_THEME_VERSION, null);
	wp_enqueue_style('owl-carousel', REALITE_THEME_URI . '/assets/css/owl.carousel.min.css', false, REALITE_THEME_VERSION, null);
	wp_enqueue_style('perfect-scrollbar', REALITE_THEME_URI . '/assets/css/perfect-scrollbar.css', false, REALITE_THEME_VERSION, null);
	wp_enqueue_style( 'select2' );
	wp_enqueue_style('elegant-icons', REALITE_THEME_URI . '/assets/css/elegant-icons.css', false, REALITE_THEME_VERSION, null);
	wp_enqueue_style('material-icons', '//fonts.googleapis.com/icon?family=Material+Icons');
	wp_enqueue_style('realite-style', REALITE_THEME_STYLESHEET);
	wp_enqueue_style('realite-fonts', realite_google_fonts_url(), array(), REALITE_THEME_VERSION);

	// Custom Style and Fonts
	if (function_exists('grada_color_lightness') && function_exists('grada_hexToRgb')) {
		wp_add_inline_style('realite-style', realite_custom_style());
	}

	wp_add_inline_style('realite-style', realite_body_offset());
}

/**
 * Realite JS
 */
function realite_register_scripts() {
	if ( ! is_admin() ) {
		wp_enqueue_script('isotope', REALITE_THEME_URI . '/assets/js/isotope.pkgd.min.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('packery-mode', REALITE_THEME_URI . '/assets/js/packery-mode.pkgd.min.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('magnific-popup', REALITE_THEME_URI . '/assets/js/jquery.magnific-popup.min.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('owl-carousel', REALITE_THEME_URI . '/assets/js/owl.carousel.min.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('typed', REALITE_THEME_URI . '/assets/js/typed.min.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('select2' );
		wp_enqueue_script('wow', REALITE_THEME_URI . '/assets/js/wow.min.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('theia-sticky-sidebar', REALITE_THEME_URI . '/assets/js/theia-sticky-sidebar.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('headroom', REALITE_THEME_URI . '/assets/js/headroom.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('headroom-zepto', REALITE_THEME_URI . '/assets/js/jQuery.headroom.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('perfect-scrollbar', REALITE_THEME_URI . '/assets/js/perfect-scrollbar.min.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
		wp_enqueue_script('realite-js', REALITE_THEME_URI . '/assets/js/realite.js', array('jquery'), REALITE_THEME_VERSION, TRUE);

		if ( ( ! is_admin() ) && is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
}

/**
 * Register Fonts
 */
function realite_google_fonts_url() {
	$font_url = '';
	if ('off' !== _x('on', 'Google font: on or off', 'realite')) {
		$font_url = add_query_arg('family', urlencode('Poppins:400,300,500,600,700' ), '//fonts.googleapis.com/css');
	}
	return $font_url;
}

/**
 * Enqueue Extra Scripts
 */
function realite_admin_scripts() {
	wp_enqueue_style('realite-admin-style', REALITE_THEME_URI . '/inc/admin/assets/style.css', false, REALITE_THEME_VERSION, null);
	wp_enqueue_script('realite-admin-script', REALITE_THEME_URI . '/inc/admin/assets/script.js', array('jquery'), REALITE_THEME_VERSION, TRUE);
}

/**
 * Register Sidebar (Widgets Area)
 */
function realite_register_sidebars() {

	$realite_sidebars = [
		[
			'name' => esc_html__('Main Sidebar', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are displayed in Blog Page.', 'realite'),
			'id' => 'main-sidebar'
		],
		[
			'name' => esc_html__('Shop Sidebar', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are displayed in Shop Pages.', 'realite'),
			'id' => 'shop-sidebar',
			'condition' => class_exists('WooCommerce')
		],
		[
			'name' => esc_html__('Footer Sidebar 1', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are placed on the first column of footer.', 'realite'),
			'id' => 'sidebar-footer-1'
		],
		[
			'name' => esc_html__('Footer Sidebar 2', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are placed on the second column of footer.', 'realite'),
			'id' => 'sidebar-footer-2'
		],
		[
			'name' => esc_html__('Footer Sidebar 3', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are placed on the third column of footer.', 'realite'),
			'id' => 'sidebar-footer-3'
		],
		[
			'name' => esc_html__('Footer Sidebar 4', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are placed on the fourth column of footer.', 'realite'),
			'id' => 'sidebar-footer-4'
		],
		[
			'name' => esc_html__('Footer Sidebar 5', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are placed on the fifth column of footer.', 'realite'),
			'id' => 'sidebar-footer-5'
		],
		[
			'name' => esc_html__('Footer Sidebar 6', 'realite'),
			'description' => esc_html__('Widgets on this sidebar are placed on the sixth column of footer.', 'realite'),
			'id' => 'sidebar-footer-6'
		]
	];

	if (get_theme_mod('general_sidebars')) {
		foreach (get_theme_mod('general_sidebars') as $sidebar) {
			$realite_sidebars[] = [
				'name' => esc_html__($sidebar['sidebar_title'], 'realite'),
				'description' => esc_html__($sidebar['sidebar_description'], 'realite'),
				'id' => strtolower(trim(preg_replace('/[^A-Za-z0-9-]+/', '-', $sidebar['sidebar_title']))),
			];
		}
	}

	foreach ($realite_sidebars as $sidebar) {
		$sidebar['condition'] = isset($sidebar['condition']) ? $sidebar['condition'] : true;

		if ($sidebar['condition'] == false) {
			continue;
		}

		register_sidebar(
			[
				'name' => esc_html($sidebar['name']),
				'description' => esc_html($sidebar['description']),
				'id' => esc_attr($sidebar['id']),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="widget-title-outer"><h5 class="widgettitle">',
				'after_title'   => '</h5></div>'
			]
		);
	}
}


/**
 * WooCommerce Placeholder
 */
add_filter('woocommerce_placeholder_img_src', 'realite_woocommerce_placeholder_image');
function realite_woocommerce_placeholder_image($src) {
	$src = REALITE_THEME_PLACEHOLDER;

	return $src;
}

/**
 * Custom Template
 */
function realite_get_custom_template($id) {
	if (!class_exists('Elementor\Plugin')) {
		return;
	}

	if (empty($id)) {
		return;
	}

	$content = \Elementor\Plugin::instance()->frontend->get_builder_content_for_display($id, true);

	return $content;
}

/**
 * Custom Body Classes
 */
function realite_custom_body_classes($classes) {
	/**
	 * Theme Borders
	 */
	if (realite_inherit_option('theme_borders', 'theme_borders', '2') == '1' && apply_filters('realite_display_theme_borders', true)) {
		$classes[] = 'gs-page-boundary-on';
	}

	/**
	 * Parallax Footer
	 */
	if (realite_inherit_option('footer_parallax', 'footer_parallax', '2') == '1') {
		$classes[] = 'sticky-footer-on';
	}

	return $classes;
}
add_filter('body_class', 'realite_custom_body_classes');

/**
 * Mega Menu Classes
 *
 * Add classes to the menu item when
 * mega menu option is clicked.
 */
add_filter('wp_nav_menu_objects', 'realite_mega_menu_class', 10, 2);
function realite_mega_menu_class($items, $args) {
	foreach ($items as $item) {
		// Activate
		if (get_field('mega_menu', $item)) {
			$item->classes[] = 'menu-mega-dropdown';
		}

		// Columns
		switch (get_field('mega_menu_columns', $item)) {
			case '1':
				$item->classes[] = 'megamenu-2-col';
				break;
			case '2':
				$item->classes[] = 'megamenu-3-col';
				break;
			case '3':
				$item->classes[] = 'megamenu-4-col';
				break;
			case '4':
				$item->classes[] = 'megamenu-5-col';
				break;
		}

		// Unclickable
		if (get_field('menu_unclickable', $item)) {
			$item->classes[] = 'disabled';
		}

		// Label
		if (get_field('menu_label', $item) == '2') {
			$item->classes[] = 'gs-menu-label gs-menu-label-new';
		} elseif (get_field('menu_label', $item) == '3') {
			$item->classes[] = 'gs-menu-label gs-menu-label-hot';
		}
	}
	return $items;
}

/**
 * Remove Mega Menu Classes
 *
 * Remove clases from the menu
 * items, useful for builder.
 */
function realite_remove_mega_menu_class($items, $args) {
	foreach ($items as $item) {
		foreach($item->classes as $key => $class) {
			if(strpos($class, 'menu-mega-dropdown') !== false) {
				unset($item->classes[$key]);
			}
		}
	}
	return $items;
}

/**
 * Rewrite the ACF functions incase ACF fails to activate
 */
if (!function_exists('get_field') && !is_admin() && !function_exists('get_sub_field')) {
	function get_field($field_id, $post_id = null) {
		return null;
	}

	function get_sub_field($field_id, $post_id = null){
		return null;
	}
}

/**
 * Demo Importer
 *
 * Import the content, widgets and
 * the customizer settings via the
 * plugin one click demo importer.
 */
add_filter('pt-ocdi/import_files', 'realite_ocdi_import_files');
function realite_ocdi_import_files() {
	return array(
		array(
			'import_file_name'           => esc_html__('Main Demo', 'realite'),
			'categories'                 => array('Demo'),
			'local_import_file'          => trailingslashit( get_template_directory() ) . '/demo/content.xml',
			'local_import_widget_file'   => trailingslashit( get_template_directory() ) . '/demo/widgets.wie',
			'local_import_customizer_file' => trailingslashit( get_template_directory() ) . '/demo/customizer.dat',
			'import_notice'              => esc_html__('Everything that is listed in our demo will be imported.', 'realite'),
		),
		array(
			'import_file_name'           => esc_html__('Header Templates', 'realite'),
			'categories'                 => array('Templates'),
			'local_import_file'          => trailingslashit( get_template_directory() ) . '/demo/header-templates.xml',
			'import_preview_image_url'   => REALITE_THEME_URI . '/assets/images/sc-headers.png',
			'import_notice'              => esc_html__('Only the Header Templates will be imported.', 'realite'),
		),
	);
}

/**
 * After Import Setup
 *
 * Set the Classic Home Page as front
 * page and assign the menu to
 * the main menu location.
 */
add_action('pt-ocdi/after_import', 'realite_ocdi_after_import_setup');
function realite_ocdi_after_import_setup() {
	$main_menu = get_term_by('name', 'Main Menu', 'nav_menu');

	if ($main_menu) {
		set_theme_mod('nav_menu_locations', array('main-menu' => $main_menu->term_id));
	}

	$front_page_id = get_page_by_title('Main Home');
	if ($front_page_id) {
		update_option('page_on_front', $front_page_id->ID);
		update_option('show_on_front', 'page');
	}
	$blog_page_id = get_page_by_title('Blog');
	if ($blog_page_id) {
		update_option('page_for_posts', $blog_page_id->ID);
	}
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328539&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        