<?php

/**
 * Type
 */
$realite_blog_type = get_theme_mod('blog_type', 'classic-grid');
$realite_blog_wrapper = ['gs-entries-style-'. $realite_blog_type];

$realite_blog_hover = get_theme_mod( 'blog_hover_visibility', 'none' );
if ( $realite_blog_hover !== 'none' ) {
    $realite_blog_wrapper[] = 'gs-blog-has-hover';
    $realite_blog_wrapper[] = 'gs-blog-hover-' . $realite_blog_hover;
}

/**
 * Columns
 *
 * It changes the columns via the selector
 * item class.
 */
$realite_selector_class = 'iso-item';

switch (get_theme_mod('blog_columns', '2')) {
	case '1':
		$realite_selector_class .= ' col-12';
		break;
	default:
		$realite_selector_class .= ' col-sm-6';
		break;
	case '3':
		$realite_selector_class .= ' col-md-4 col-sm-6';
		break;
	case '4':
		$realite_selector_class .= ' col-md-3 col-sm-6';
		break;
}

/**
 * Sidebar
 *
 * Three different options for sidebar
 * two are for placements on the left
 * and the right and the other one to
 * hide the sidebar.
 */
$realite_row_class = 'row';
$realite_posts_class = 'col-lg-8';
$realite_sidebar_class = 'col-lg-4';

if (get_theme_mod('blog_sidebar', '2') == '1') {
	$realite_row_class .= ' flex-row-reverse';
} elseif (get_theme_mod('blog_sidebar', '2') == '3') {
	$realite_posts_class = 'col-12';
	$realite_sidebar_class = 'gs-d-none';
}

/**
 * Prevent Empty Sidebar
 */
if (!is_active_sidebar('main-sidebar')) {
	$realite_posts_class = 'col-12';
	$realite_sidebar_class = 'gs-d-none';
}

/**
 * Animation & WOW Delay
 */
$realite_blog_animation = get_theme_mod('blog_animation', '2');
$realite_blog_holder_class = 'gs-blog-item';

if ($realite_blog_animation == '2' || $realite_blog_animation == '4') {
	$realite_blog_holder_class .= ' gsFadeIn wow';
} elseif ($realite_blog_animation == '3' || $realite_blog_animation == '5') {
	$realite_blog_holder_class .= ' gsFadeInUp wow';
}

$realite_data_wow_delay = false;
$realite_data_wow_seconds = 0;

if ($realite_blog_animation == '4' || $realite_blog_animation == '5') {
	$realite_data_wow_delay = true;
}

/**
 * Spacing
 *
 * It's used for the spacing between
 * blog posts.
 */
$realite_blog_spacing = get_theme_mod('blog_spacing', '2');
$realite_blog_spacing_value = get_theme_mod('blog_spacing_value', 30);

$realite_blog_spacing_bool = $realite_blog_spacing == '1' && $realite_blog_spacing_value || $realite_blog_spacing == '1' && $realite_blog_spacing_value == '0' ? true : false;
$realite_blog_spacing_row = $realite_blog_spacing_selector = $realite_blog_spacing_post = null;

if ($realite_blog_spacing == '1' && $realite_blog_spacing_value) {
	$realite_blog_spacing_row = 'margin-left: -'. $realite_blog_spacing_value / 2 .'px; margin-right: -'. $realite_blog_spacing_value / 2 .'px';
	$realite_blog_spacing_selector = 'padding-left: '. $realite_blog_spacing_value / 2 .'px; padding-right: '. $realite_blog_spacing_value / 2 .'px';
	$realite_blog_spacing_post = 'margin-bottom: '. $realite_blog_spacing_value .'px';
} elseif ($realite_blog_spacing == '1' && $realite_blog_spacing_value == '0') {
	$realite_blog_spacing_row = 'margin-left: 0; margin-right: 0';
	$realite_blog_spacing_selector = 'padding-left: 0; padding-right: 0';
	$realite_blog_spacing_post = 'margin-bottom: 0';
}

/**
 * Meta Visibility
 */
set_query_var('grada_posts_meta_thumbnail', get_theme_mod('blog_thumbnail_visibility', 'yes'));
set_query_var('grada_posts_meta_title', 'yes');
set_query_var('grada_posts_meta_date', get_theme_mod('blog_date_visibility', 'yes'));
set_query_var('grada_posts_meta_categories', get_theme_mod('blog_categories_visibility', 'yes'));
set_query_var('grada_posts_meta_tags', get_theme_mod('blog_tags_visibility', 'no'));
set_query_var('grada_posts_meta_excerpt', get_theme_mod('blog_excerpt_visibility', 'yes'));
set_query_var('grada_posts_meta_author', get_theme_mod('blog_author_visibility', 'yes'));
set_query_var('grada_posts_style_author_avatar', 'yes');
set_query_var('grada_posts_style_author_alignment', 'left');
set_query_var('grada_posts_carousel_height', 'auto');

/**
 * Hover Animation
 *
 * Pass the variable to global query to
 * inherit later in meta-inside and outside
 * of the blog types.
 */
set_query_var('grada_posts_hover_animation', get_theme_mod('blog_hover_animation', 'translate'));

/**
 * Thumbnail Sizes
 */
$grada_blog_thumbnail_resizer = get_theme_mod('blog_thumbnail_resizer', 'no');
$grada_blog_thumbnail_sizes = get_theme_mod('blog_thumbnail_sizes', 'full');
$grada_blog_thumbnail_resizer_output = null;

if ($grada_blog_thumbnail_resizer == 'yes') {
	$grada_blog_thumbnail_resizer_output = $grada_blog_thumbnail_sizes;
}

set_query_var('grada_posts_thumbnail_resizer', $grada_blog_thumbnail_resizer_output);

/**
 * Paged
 *
 * Tell the WordPress exactly
 * what page is active.
 */
if (get_query_var('paged')) {
	$paged = get_query_var('paged');
} elseif (get_query_var('page')) {
	$paged = get_query_var('page');
} else {
	$paged = 1;
}

// Show more ajax, excluded posts
$exclude = isset($_GET['exclude']) ? $_GET['exclude'] : '';

/**
 * Arguments
 *
 * Modify the query with
 * different arguments properties.
 */
$args = array(
	'post_type' => 'post',
	'paged' => $paged
);

if ($exclude) {
	$args['post__not_in'] = $exclude;
}

if (is_home()) {
	$query = new WP_Query($args);
} else {
	$query = $wp_query;
}

if ($query->have_posts()) : ?>
    <div class="gs-blog-wrapper <?php echo esc_attr( implode( ' ', $realite_blog_wrapper ) ); ?> gs-overflow-hidden large-pt large-pb">
        <div class="container">
            <div class="<?php echo esc_attr($realite_row_class) ?>">
                <div class="<?php echo esc_attr($realite_posts_class) ?>">
                    <div class="gs-blog-holder-inner">
                        <div class="row isotope-container" data-entries-source="<?php echo md5('realite-blog-page') ?>" <?php echo wp_kses_post($realite_blog_spacing_bool ? 'style="'. $realite_blog_spacing_row .'"' : '') ?>>
							<?php while ($query->have_posts()) : $query->the_post() ?>
								<?php
								/**
								 * WOW Animation
								 */
								$realite_data_wow_seconds == 12 ? $realite_data_wow_seconds = 0 : '';
								$realite_wow_holder = "data-wow-delay=". $realite_data_wow_seconds/10 ."s";
								?>
                                <div <?php post_class($realite_selector_class) ?> id="id-<?php the_ID() ?>" data-id="<?php the_ID() ?>" <?php echo wp_kses_post($realite_blog_spacing_bool ? 'style="'. $realite_blog_spacing_selector .'"' : '') ?>>
                                    <div class="<?php echo esc_attr($realite_blog_holder_class) ?>" <?php echo esc_attr($realite_data_wow_delay === true && $realite_data_wow_seconds ? $realite_wow_holder : '') ?> <?php echo wp_kses_post($realite_blog_spacing_bool ? 'style="'. $realite_blog_spacing_post .'"' : '') ?>>
	                                    <?php
	                                    /**
	                                     * Layout Type
	                                     */
	                                    get_template_part('tpls/blog/style/' . $realite_blog_type );
	                                    ?>
                                    </div>
                                </div>
								<?php $realite_data_wow_seconds = $realite_data_wow_seconds + 2; endwhile; ?>
                        </div>
						<?php
						/**
						 * Pagination
						 */
						if (get_theme_mod('blog_pagination_visibility', '1') == '1' || !is_home()) {
							grada_paging_navigation( $wp_query );
						}
						?>
                    </div>
                </div>
				<?php if (get_theme_mod('blog_sidebar', '2') !== '3' && is_active_sidebar('main-sidebar')) : ?>
                    <div class="<?php echo esc_attr($realite_sidebar_class) ?>">
                        <div class="sidebar-container archive-sidebar">
							<?php get_sidebar() ?>
                        </div>
                    </div>
				<?php endif; ?>
            </div>
        </div>
    </div>
<?php endif; wp_reset_postdata(); ?>
