<?php
/**
 * Default Logo
 */
$realite_logo_display = $realite_light_logo_display = $realite_logo_style = [];

/**
 * Logos
 */
$realite_dark_logo = get_theme_mod('header_dark_logo');
$realite_light_logo = get_theme_mod('header_light_logo');
$realite_text_logo = get_theme_mod('header_logo_text');
$realite_custom_dark_logo = get_field('header_dark_logo');
$realite_custom_light_logo = get_field('header_light_logo');

/**
 * Logo Attributes
 */
$realite_logo_width = get_theme_mod('header_logo_width');
$realite_logo_height = get_theme_mod('header_logo_height');
$realite_logo_custom_width = get_field('header_logo_width');
$realite_logo_custom_height = get_field('header_logo_height');
$realite_logo_text_size = get_theme_mod('header_logo_text_size');

/**
 * Logo Classes & Extensions
 */
$realite_logo_class = 'gs-logo gs-logo-img';
$realite_dark_logo_img_class = 'logo-img-holder logo-default';
$realite_light_logo_img_class = 'logo-img-holder logo-light';
$realite_logo_ext = 'png';

/**
 * Dark Logo
 */
if ($realite_custom_dark_logo) {
	$realite_logo_display = $realite_custom_dark_logo;
} elseif ($realite_custom_light_logo) {
	$realite_logo_display = $realite_custom_light_logo;
} elseif ($realite_dark_logo) {
	$realite_logo_display = $realite_dark_logo;
} elseif ($realite_light_logo) {
	$realite_logo_display = $realite_light_logo;
} else {
	$realite_logo_class = 'gs-logo a-logo--text';
}

/**
 * Light Logo
 */
if ($realite_custom_light_logo) {
	$realite_light_logo_display = $realite_custom_light_logo;
} elseif ($realite_light_logo) {
	$realite_light_logo_display = $realite_light_logo;
}

/**
 * Logo Attributes
 */
if ($realite_logo_display) {
	if ($realite_logo_custom_width) {
		$realite_logo_style[] = 'width: '. $realite_logo_custom_width .'px';
	} elseif ($realite_logo_width) {
		$realite_logo_style[] = 'width: '. $realite_logo_width .'px';
	} elseif (!strpos(wp_get_attachment_url($realite_logo_display), '.svg')) {
		$realite_logo_style[] = 'width: '. wp_get_attachment_metadata($realite_logo_display)['width'] .'px';
	}

	if ($realite_logo_custom_height) {
		$realite_logo_style[] = 'height: '. $realite_logo_custom_height .'px';
	} elseif ($realite_logo_height) {
		$realite_logo_style[] = 'height: '. $realite_logo_height .'px';
	} elseif (!strpos(wp_get_attachment_url($realite_logo_display), '.svg')) {
		$realite_logo_style[] = 'height: '. wp_get_attachment_metadata($realite_logo_display)['height'] .'px';
	}
}

/**
 * Logo Text Size
 */
if ($realite_logo_text_size && !$realite_logo_display && !$realite_light_logo_display) {
	$realite_logo_style[] = 'font-size: '. $realite_logo_text_size .'px';
}



?>
<div class="<?php echo esc_attr($realite_logo_class) ?>">
	<a href="<?php echo esc_url(home_url('/')); ?>" style="<?php echo esc_attr(implode(';', $realite_logo_style)) ?>">
		<?php
		// Dark Logo
		if ($realite_logo_display) {
			echo wp_get_attachment_image($realite_logo_display, 'full', '', array('class' => $realite_dark_logo_img_class, 'alt' => get_bloginfo('name')));
		} elseif ($realite_text_logo) {
			echo esc_attr($realite_text_logo);
		} else {
			bloginfo('name');
		}

		// Light Logo
		if ($realite_light_logo_display) {
			echo wp_get_attachment_image($realite_light_logo_display, 'full', '', array('class' => $realite_light_logo_img_class, 'alt' => get_bloginfo('name')));
		}
		?>
	</a>
</div>