<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined('ABSPATH') || exit;

get_header();

get_template_part('templates/hero/taxonomy');

global $realite_data_wow_seconds, $realite_data_wow_delay;

/**
 * Type
 */
$realite_shop_type = get_theme_mod('shop_type', 'classic-grid');
$realite_products_holder = 'gs-entries-wrapper gs-woo-product-list gs-woo-product-list--' . $realite_shop_type;

/**
 * Sidebar
 */
$realite_row_class = 'row';
$realite_products_class = 'col-lg-8';
$realite_sidebar_class = 'col-lg-4';

if (get_theme_mod('shop_sidebar', '2') == '1') {
	$realite_row_class .= ' flex-row-reverse';
} elseif (get_theme_mod('shop_sidebar', '2') == '3' || !is_active_sidebar('shop-sidebar')) {
	$realite_products_class = 'col-12';
	$realite_sidebar_class = 'gs-d-none';
}

/**
 * Animation
 */
$realite_data_wow_delay = false;
$realite_data_wow_seconds = 0;

if (get_theme_mod('shop_animation', 'fade-in') == 'fade-in-delay' || get_theme_mod('shop_animation', 'fade-in') == 'fade-in-up-delay') {
	$realite_data_wow_delay = true;
}

/**
 * Spacing
 *
 * It's used for the spacing between
 * shop products.
 */
$realite_shop_spacing = get_theme_mod('shop_spacing');
$realite_shop_spacing_value = get_theme_mod('shop_spacing_value');

$realite_shop_spacing_bool = $realite_shop_spacing == 'yes' || $realite_shop_spacing_value == '0' ? true : false;
$realite_shop_spacing_row = null;

if ($realite_shop_spacing == 'yes' && $realite_shop_spacing_value) {
	$realite_shop_spacing_row = 'margin-left: -'. $realite_shop_spacing_value / 2 .'px; margin-right: -'. $realite_shop_spacing_value / 2 .'px';
} elseif ($realite_shop_spacing == 'yes' && $realite_shop_spacing_value == '0') {
	$realite_shop_spacing_row = 'margin-left: 0; margin-right: 0';
}

/**
 * Paged
 *
 * Tell the WordPress exactly
 * what page is active.
 */
if (get_query_var('paged')) {
	$paged = get_query_var('paged');
} elseif (get_query_var('page')) {
	$paged = get_query_var('page');
} else {
	$paged = 1;
}

/**
 * Thumbnail Sizes
 */
$grada_shop_thumbnail = get_theme_mod('shop_thumbnail_resizer', 'yes');
$grada_shop_thumbnail_sizes = get_theme_mod('shop_thumbnail_sizes', 'full');
$grada_shop_thumbnail_output = null;

if ($grada_shop_thumbnail == 'yes') {
	$grada_shop_thumbnail_output = $grada_shop_thumbnail_sizes;
}

set_query_var('grada_posts_thumbnail_resizer', $grada_shop_thumbnail_output);

// Show More with Ajax
$exclude = isset($_GET['exclude']) ? $_GET['exclude'] : '';

/**
 * Query Arguments
 *
 * Modify the query with
 * different arguments properties.
 */
$args = array(
	'post_type' => 'product',
	'paged' => $paged,
	'posts_per_page' => get_theme_mod('shop_ppp')
);

if ($exclude) {
	$args['post__not_in'] = $exclude;
}

/**
 * Catalog Orderby
 */
$orderby_options = [
	'menu_order' => esc_html__('Default sorting', 'realite'),
	'popularity' => esc_html__('Sort by popularity', 'realite'),
	'rating'     => esc_html__('Sort by average rating', 'realite'),
	'date'       => esc_html__('Sort by newness', 'realite'),
	'price'      => esc_html__('Sort by price: low to high', 'realite'),
	'price-desc' => esc_html__('Sort by price: high to low', 'realite')
];

$catalog_orderby_options = apply_filters('woocommerce_catalog_orderby', $orderby_options);

/**
 * Change default order
 */
if (isset($_GET['orderby'])) {
	$orderby = wc_clean(wp_unslash($_GET['orderby']));
	$show_default_orderby = 'default';
} else {
	switch (get_theme_mod('shop_catalog_ordering_default', 'menu_order')) {
		default:
			$show_default_orderby = $orderby = 'default';
			break;
		case 'popularity':
			$show_default_orderby = $orderby = 'popularity';
			break;
		case 'rating':
			$show_default_orderby = $orderby = 'rating';
			break;
		case 'date':
			$show_default_orderby = $orderby = 'date';
			break;
		case 'price':
			$show_default_orderby = $orderby = 'price';
			break;
		case 'price-desc':
			$show_default_orderby = $orderby = 'price-desc';
			break;
	}
}

/**
 * Modify Query for Orderby
 */
switch ($orderby) {
	case 'default':
		$args['orderby'] = 'menu_order';
		$args['order'] = 'asc';
		break;
	case 'popularity':
		$args['orderby'] = 'meta_value_num';
		$args['meta_key'] = 'total_sales';
		$args['order'] = 'desc';
		break;
	case 'rating':
		$args['orderby'] = 'meta_value_num';
		$args['meta_key'] = '_wc_average_rating';
		$args['order'] = 'desc';
		break;
	case 'date':
		$args['orderby'] = 'date';
		$args['meta_key'] = '';
		$args['order'] = 'desc';
		break;
	case 'price':
		$args['orderby'] = 'meta_value_num';
		$args['meta_key'] = '_price';
		$args['order'] = 'asc';
		break;
	case 'price-desc':
		$args['orderby'] = 'meta_value_num';
		$args['meta_key'] = '_price';
		$args['order'] = 'desc';
		break;
}

$query = new WP_Query($args);

/**
 * Breadcrumb
 */
$realite_page_breadcrumb = realite_inherit_option('general_breadcrumb', 'breadcrumbs_shop_visibility', '2', true);
realite_breadcrumbs($realite_page_breadcrumb, get_theme_mod('breadcrumbs_separator'));

do_action('realite_open_container');
?>
	<div class="gs-woo-page large-pt large-pb">
		<?php
		/**
		 * Hook: woocommerce_archive_description.
		 *
		 * @hooked woocommerce_taxonomy_archive_description - 10
		 * @hooked woocommerce_product_archive_description - 10
		 */
		do_action('woocommerce_archive_description');
		?>
		<div class="<?php echo esc_attr($realite_row_class) ?>">
			<div class="<?php echo esc_attr($realite_products_class) ?>">
				<?php
				/**
				 * Result Count
				 */
				$realite_result_count = get_theme_mod('shop_result_count', 'show');
				$realite_result_count_class = 'col-sm-6';

				/**
				 * Catalog Ordering
				 */
				$realite_catalog_ordering = get_theme_mod('shop_catalog_ordering', 'show');
				$realite_catalog_ordering_class = 'col-sm-6';

				$realite_catalog_ordering == 'hide' ? $realite_result_count_class = 'col-12' : '';
				$realite_result_count == 'hide' ? $realite_catalog_ordering_class = 'col-12' : '';

				if ($realite_result_count == 'show' || $realite_catalog_ordering == 'show') :
					?>
					<div class="gs-shop-header medium-pb">
						<div class="row align-items-center">
							<?php if ($realite_result_count == 'show') : ?>
								<div class="<?php echo esc_attr($realite_result_count_class) ?>">
									<?php woocommerce_result_count(); ?>
								</div>
							<?php endif; ?>
							<?php if ($realite_catalog_ordering == 'show') : ?>
								<div class="<?php echo esc_attr($realite_catalog_ordering_class) ?>">
									<?php
									wc_get_template('loop/orderby.php', array(
										'catalog_orderby_options' => $catalog_orderby_options,
										'orderby' => $orderby,
										'show_default_orderby' => $show_default_orderby,
									));
									?>
								</div>
							<?php endif; ?>
						</div>
					</div>
				<?php endif; ?>
				<div class="<?php echo esc_attr($realite_products_holder) ?>">
					<div class="row masonry fitRows" data-masonry-id="archive-products" <?php echo wp_kses_post($realite_shop_spacing_bool ? 'style="'. $realite_shop_spacing_row .'"' : '') ?>>
						<?php while ($query->have_posts()) : $query->the_post(); ?>
							<?php
							wc_get_template_part('content', 'product');

							$realite_data_wow_seconds = $realite_data_wow_seconds + 2;
							$realite_data_wow_seconds == 12 ? $realite_data_wow_seconds = 0 : '';
							?>
						<?php endwhile; ?>
					</div>
					<?php grada_paging_navigation($query); ?>
				</div>
			</div>
			<?php if (get_theme_mod('shop_sidebar', '2') !== '3' && is_active_sidebar('shop-sidebar')) : ?>
				<div class="<?php echo esc_attr($realite_sidebar_class) ?>">
					<div class="sidebar-container">
						<?php get_sidebar('shop') ?>
					</div>
				</div>
			<?php endif; ?>
		</div>
	</div>
<?php
do_action('realite_close_container');

get_footer();