jQuery(document).ready(function($) {
  var themeBordersHeight;

  // Theme Borders Height
  function gradaThemeBordersHeight() {
    if ($('.gs-page-boundary').length) {
      themeBordersHeight = $('.gs-border-top').outerHeight();
    }
  }

  /**
   * Justified Gallery
   */
  function grada_justified_gallery() {
    var justified_gallery = $('.justified');

    if (justified_gallery) {
      justified_gallery.each(function() {
        var options = $(this)
          .parents('.elementor-element.elementor-widget')
          .data('settings');

        var rowHeight = options['posts_justified_height'],
          margins = options['posts_justified_margins'],
          lastRowOption = options['posts_justified_last_row'];

        if (margins && margins !== 0) {
          $(this).css('margin-left', -margins);
          $(this).css('margin-right', -margins);
        }

        $(this).justifiedGallery({
          rowHeight: rowHeight ? rowHeight : 200,
          margins: margins ? margins : 1,
          selector: '.iso-item',
          imgSelector: '.entry-image-ratio img',
          captions: false,
          waitThumnbailsLoad: false,
          lastRow: lastRowOption ? lastRowOption : 'justify'
        });
      });
    }
  }

  // Perfect Scrollbar
  if ($('.elementor-section').hasClass('gs-locked-section-on')) {
    new PerfectScrollbar('.gs-locked-section-on');
  }

  /**
   * Mega Menu Calculation
   */
  function gradaCalculateMegaMenu() {
    $('.elementor-widget-grada-nav-menu').each(function() {
      var $menu = $(this);

      var $navHolder = $menu.find('.widget-navigation-menu-wrapper');

      if (!$navHolder.hasClass('menu-navigation-regular')) {
        return;
      }

      var $subMenu = $navHolder.find('.menu-mega-dropdown > .sub-menu');
      var $elementorContainer = $menu.parents('.elementor-container');

      var columnPadding = parseInt(
        $menu.parents('.elementor-column-wrap').css('paddingLeft')
      );

      var containerOffset = $elementorContainer.offset().left;
      var subMenuOffset = $navHolder.offset().left;

      var width = $elementorContainer.outerWidth() - columnPadding * 2;
      var offset = containerOffset - subMenuOffset + columnPadding;

      $subMenu.css({
        width: width,
        left: offset
      });
    });
  }

  /**
   * Mobile Menu Calculation
   */
  function gradaCalculateMobileMenu() {
    $('.navigation-menu-full-width.elementor-widget-grada-nav-menu').each(function() {
      var $menu = $(this);

      var $navHolder = $menu.find('.widget-mobile-nav-menu-wrapper');
      var $mobileMenu = $navHolder.find('.mobile-nav-menu');
      var $elementorContainer = $menu.parents('.elementor-container');

      var columnPadding = parseInt(
        $menu.parents('.elementor-column-wrap').css('paddingLeft')
      );

      var columnLeftMargin = parseInt(
        $menu.find('.elementor-widget-container').css('marginLeft')
      );

      columnLeftMargin = columnLeftMargin ? columnLeftMargin : 0;

      var containerOffset = $elementorContainer.offset().left;
      var mobileMenuOffset = $navHolder.offset().left;

      var width = $elementorContainer.outerWidth() - columnPadding * 2;
      var offset =
        containerOffset - mobileMenuOffset + columnPadding + columnLeftMargin;

      $mobileMenu.css({
        width: width,
        left: offset
      });
    });
  }

  /**
   * Hamburger Menu
   */
  function gradaHamburgerMenu() {
    $('.elementor-widget-grada-nav-menu').each(function() {
      var $menu = $(this);

      $menu
        .find('.widget-mobile-nav-menu-wrapper .widget-mobile-nav-btn')
        .on('click', function(e) {
          e.stopPropagation();
          e.preventDefault();

          $menu
            .find('.widget-mobile-nav-menu-wrapper .mobile-nav-menu')
            .toggleClass('active');

          $menu
            .find(
              '.widget-mobile-nav-menu-wrapper .mobile-nav-menu .menu-item-has-children > .submenu-icon'
            )
            .removeClass('active');

          $menu
            .find('.widget-mobile-nav-menu-wrapper .mobile-nav-menu')
            .find('.sub-menu')
            .slideUp('fast');
        });
    });
  }

  function gradaLockedHiddenSections() {
    var $hidden_section = $('.gs-locked-section-on');
    if (
      $hidden_section.is('.elementor-hidden-tablet') &&
      $(window).width() > 730 &&
      $(window).width() < 1025
    ) {
      $hidden_section.hide();
    } else if (
      $hidden_section.is('.elementor-hidden-phone') &&
      $(window).width() < 730
    ) {
      $hidden_section.hide();
    } else {
      $hidden_section.show();
    }
  }

  function gradaMenuActiveOnScroll(event) {
    var scrollPosition = $(document).scrollTop();
    $('.menu-navigation-vertical ul li a').each(function() {
      var currentLink = $(this);
      var $parent = $(this).parents('.elementor-widget-grada-nav-menu');

      if (
        $parent.hasClass('navigation-menu-active-yes') &&
        currentLink.attr('href') !== '#' &&
        currentLink.attr('href').indexOf('#') !== -1
      ) {
        var ref = currentLink.attr('href').split('#');
        ref = typeof ref[1] !== 'undefined' ? ref[1] : ref[0];
        var refElement = $('#' + ref);
        if (refElement.length !== 0) {
          if (
            refElement.position().top <= scrollPosition &&
            refElement.position().top + refElement.height() > scrollPosition
          ) {
            currentLink.parents('li').addClass('active');
          } else {
            currentLink.parents('li').removeClass('active');
          }
        }
      }
    });
  }

  gradaLockedHiddenSections();
  gradaCalculateMegaMenu();
  gradaCalculateMobileMenu();
  gradaHamburgerMenu();
  grada_justified_gallery();
  gradaMenuActiveOnScroll();

  $(window).on('resize', function() {
    gradaLockedHiddenSections();
    gradaCalculateMegaMenu();
    gradaCalculateMobileMenu();
  });

  // Init Theme Borders Height
  gradaThemeBordersHeight();

  $('.gs-locked-section-invisible .gs-close-btn').css(
    'margin',
    themeBordersHeight
  );

  // Events
  $(window).on('resize', function() {
    if ('ontouchstart' in window || navigator.maxTouchPoints) {
      return;
    }

    gradaThemeBordersHeight();
  });

  $(document).on('scroll', gradaMenuActiveOnScroll);
});
