<?php
/**
 * Posts > Content Options > Query
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

/**
 * Auto Query
 */
$this->add_control(
	'posts_auto_query',
	[
		'label' => esc_html__('Auto Query', 'realite-plugin'),
		'description' => esc_html__('Can be useful when used for related posts or assigned to other archive pages. Doesn\'t work in normal pages, only in singles or archives.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'return_value' => 'yes',
		'default' => 'no',
		'condition' => [
			'posts_layout_type!' => 'metro'
		]
	]
);

/**
 * Normal Query
 */
$this->add_control(
	'posts_query_normal_post',
	[
		'label' => esc_html__('Query', 'realite-plugin'),
		'description' => __('Select the categories you want to get the posts from. <br /> <small> Note: If no category is selected all posts will be displayed.</small>', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT2,
		'label_block' => true,
		'options' => $this->grada_return_taxonomies('category'),
		'multiple' => true,
		'conditions' => [
			'terms' => [
				[
					'name' => 'posts_auto_query',
					'operator' => '!=',
					'value' => 'yes',
				],
				[
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'posts_layout',
							'operator' => '==',
							'value' => 'carousel'
						],
						[
							'name' => 'posts_layout_type',
							'operator' => '!==',
							'value' => 'metro',
						],
					]
				]
			],
		]
	]
);

/**
 * Metro Query
 */
$this->add_control(
	'posts_query_metro_post',
	[
		'label' => esc_html__('Query', 'realite-plugin'),
		'description' => __('Select the posts you want to show in metro. <br /><small>Note: Do not select the same item two times, it may cause issues.</small>', 'realite-plugin'),
		'prevent_empty' => false,
		'type' => Controls_Manager::REPEATER,
		'fields' => [
			[
				'name' => 'post_id',
				'label' => esc_html__('Post', 'realite-plugin'),
				'description' => esc_html__('Select the post.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => $this->grada_return_posts('post')
			],
			[
				'name' => 'post_column',
				'label' => esc_html__('Column', 'realite-plugin'),
				'description' => esc_html__('Select the post column.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'1-column' => esc_attr__('1 Column', 'realite-plugin'),
					'2-column' => esc_attr__('2 Column', 'realite-plugin'),
					'3-column' => esc_attr__('3 Column', 'realite-plugin'),
					'4-column' => esc_attr__('4 Column', 'realite-plugin'),
					'5-column' => esc_attr__('5 Column', 'realite-plugin'),
					'6-column' => esc_attr__('6 Column', 'realite-plugin'),
					'7-column' => esc_attr__('7 Column', 'realite-plugin'),
					'8-column' => esc_attr__('8 Column', 'realite-plugin'),
					'9-column' => esc_attr__('9 Column', 'realite-plugin'),
					'10-column' => esc_attr__('10 Column', 'realite-plugin'),
					'11-column' => esc_attr__('11 Column', 'realite-plugin'),
					'12-column' => esc_attr__('12 Column', 'realite-plugin')
				],
				'default' => '3-column'
			],
		],
		'conditions' => [
			'relation' => 'and',
			'terms' => [
				[
					'name' => 'posts_layout',
					'operator' => '==',
					'value' => 'isotope',
				],
				[
					'name' => 'posts_layout_type',
					'operator' => '==',
					'value' => 'metro',
				],
			],
		]
	]
);

/**
 * Order and Orderby
 */
$this->add_control(
	'posts_query_order',
	[
		'label' => esc_html__('Order', 'realite-plugin'),
		'description' => esc_html__('Change the order of the query, ascending order from lowest to highest values and so on.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'ASC' => esc_html__('Ascending', 'realite-plugin'),
			'DESC' => esc_html__('Descending', 'realite-plugin')
		],
		'default' => 'ASC',
		'condition' => [
			'posts_layout_type!' => 'metro'
		]
	]
);

$this->add_control(
	'posts_query_orderby',
	[
		'label' => esc_html__('Orderby', 'realite-plugin'),
		'description' => esc_html__('Sort retrieved posts by parameter. Defaults to menu order.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'post_date' => esc_html__('Date', 'realite-plugin'),
			'rand' => esc_html__('Random', 'realite-plugin'),
			'relevance' => esc_html__('Relevance', 'realite-plugin'),
			'menu_order' => esc_html__('Menu Order', 'realite-plugin')
		],
		'default' => 'menu_order',
		'condition' => [
			'posts_layout_type!' => 'metro'
		]
	]
);

/**
 * Posts Per Page
 */
$this->add_control(
	'posts_ppp',
	[
		'label'   => esc_html__('Posts Per Page', 'realite-plugin'),
		'description' => esc_html__('Enter the number of posts you want to display on the first page, a pagination will be created if there are more posts than this number.', 'realite-plugin'),
		'type'    => Controls_Manager::NUMBER,
		'default' => 10,
		'min'     => 1,
		'max'     => 10000,
		'step'    => 1
	]
);