
<?php
/**
 * Gallery Images > Content Options > Functionality
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

$this->add_control(
	'gallery_images_layout',
	[
		'label' => esc_html__('Layout', 'realite-plugin'),
		'description' => esc_html__('Select the layout of posts.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'isotope' => esc_html__('Isotope', 'realite-plugin'),
			'carousel' => esc_html__('Carousel', 'realite-plugin')
		],
		'default' => 'isotope'
	]
);

$this->add_control(
	'gallery_images_layout_type',
	[
		'label' => esc_html__('Layout Type', 'realite-plugin'),
		'description' => esc_html__('Select the layout type of isotope.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'masonry' => esc_html__('Masonry', 'realite-plugin'),
			'metro' => esc_html__('Metro', 'realite-plugin'),
			'fitrows' => esc_html__('FitRows', 'realite-plugin'),
			'justified' => esc_html__('Justified', 'realite-plugin')
		],
		'default' => 'masonry',
		'conditions' => [
			'terms' => [
				[
					'name' => 'gallery_images_layout',
					'operator' => '==',
					'value' => 'isotope'
				],
			]
		]
	]
);

$this->add_control(
	'gallery_images_layout_model',
	[
		'label' => esc_html__('Layout Model', 'realite-plugin'),
		'description' => esc_html__('Select the layout model.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'info-overlay' => esc_html__('Info Overlay', 'realite-plugin'),
			'info-bottom' => esc_html__('Info Bottom', 'realite-plugin')
		],
		'default' => 'info-overlay',
		'condition' => [
			'gallery_images_layout_type!' => 'justified'
		]
	]
);

$this->add_control(
	'gallery_images_lightbox',
	[
		'label' => esc_html__('Lightbox', 'realite-plugin'),
		'description' => esc_html__('Enable the lightbox for the images, the images will open in a large slideshow when clicked.'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'label_on' => esc_html__('Yes', 'realite-plugin'),
		'label_off' => esc_html__('No', 'realite-plugin'),
		'return_value' => 'yes',
		'default' => 'no'
	]
);

/**
 * Categories
 *
 * Get all categories and
 * display them in a select, it's up
 * to the post type to change this category
 */
$media_categories = [];
$media_terms = get_terms('gallery_category', array('hide_empty' => false));
if ($media_terms && !is_wp_error($media_terms)) {
	foreach ($media_terms as $term) {
		$media_categories[$term->slug] = $term->name;
	}
}

$this->add_control(
	'gallery_images_filters_visibility',
	[
		'label' => esc_html__('Filters', 'realite-plugin'),
		'description' => esc_html__('Make the media gallery sortable, do not forget to add filters in the repeater.'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'label_on' => esc_html__('Show', 'realite-plugin'),
		'label_off' => esc_html__('Hide', 'realite-plugin'),
		'return_value' => 'yes',
		'default' => 'no',
		'condition' => [
			'gallery_images_layout' => 'isotope'
		],
	]
);

$this->add_control(
	'gallery_images_filters',
	[
		'label'   => esc_html__('Filters Query', 'realite-plugin'),
		'description' => esc_html__('Add the filters.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT2,
		'label_block' => true,
		'options' => $media_categories,
		'multiple' => true,
		'conditions' => [
			'terms' => [
				[
					'name' => 'gallery_images_layout',
					'operator' => '==',
					'value' => 'isotope'
				],
				[
					'name' => 'gallery_images_filters_visibility',
					'operator' => '==',
					'value' => 'yes'
				],
			]
		]
	]
);

/**
 * Query
 */
$this->add_control(
	'gallery_images_query_normal',
	[
		'label' => esc_html__('Query', 'realite-plugin'),
		'description' => esc_html__('Add images to the gallery.', 'realite-plugin'),
		'type' => Controls_Manager::REPEATER,
		'fields' => [
			[
				'name' => 'query_type',
				'label' => esc_html__('Type', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'image' => [
						'title' => esc_html__('Image', 'realite-plugin'),
						'icon' => 'fa fa-image',
					],
					'video' => [
						'title' => esc_html__('Video', 'realite-plugin'),
						'icon' => 'fa fa-video-camera',
					],
				],
				'default' => 'image',
				'toggle' => false,
				'label_block' => false,
			],
			[
				'name' => 'query_image',
				'label' => esc_html__('Image', 'realite-plugin'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => get_template_directory_uri() . '/assets/images/placeholder.png'
				],
			],
			[
				'name' => 'query_video_link',
				'label' => esc_html__('Video Link', 'realite-plugin'),
				'description' => esc_html__('YouTube link or video file (mp4 is recommended).', 'realite-plugin'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'query_type' => 'video'
				]
			],
			[
				'name' => 'query_title',
				'label' => esc_html__('Title', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__('Title', 'realite-plugin')
			],
			[
				'name' => 'query_subtitle',
				'label' => esc_html__('Subtitle', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::TEXT
			],
			[
				'name' => 'query_category',
				'label' => esc_html__('Category', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => $media_categories,
				'multiple' => true
			],
			[
				'name' => 'query_url',
				'label' => esc_html__('URL', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::URL,
				'condition' => [
					'query_type' => 'image'
				]
			],
			[
				'name' => 'query_description',
				'label' => esc_html__('Description', 'realite-plugin'),
				'description' => __('Enter the description. <br /><small>Note: Description is not visible on meta inside.</small>', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::TEXTAREA
			]
		],
		'title_field' => '{{{ query_title }}}',
		'conditions' => [
			'terms' => [
				[
					'name' => 'gallery_images_layout_type',
					'operator' => '!=',
					'value' => 'metro'
				],
			]
		]
	]
);

$this->add_control(
	'gallery_images_query_metro',
	[
		'label' => esc_html__('Query', 'realite-plugin'),
		'description' => esc_html__('Add images to the gallery.', 'realite-plugin'),
		'type' => Controls_Manager::REPEATER,
		'fields' => [
			[
				'name' => 'query_type',
				'label' => esc_html__('Type', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'image' => [
						'title' => esc_html__('Image', 'realite-plugin'),
						'icon' => 'fa fa-image',
					],
					'video' => [
						'title' => esc_html__('Video', 'realite-plugin'),
						'icon' => 'fa fa-video-camera',
					],
				],
				'default' => 'image',
				'toggle' => false,
				'label_block' => false,
			],
			[
				'name' => 'query_image',
				'label' => esc_html__('Image', 'realite-plugin'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => get_template_directory_uri() . '/assets/images/placeholder.png'
				]
			],
			[
				'name' => 'query_video_link',
				'label' => esc_html__('Video Link', 'realite-plugin'),
				'description' => esc_html__('YouTube link or video file (mp4 is recommended).', 'realite-plugin'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'query_type' => 'video'
				]
			],
			[
				'name' => 'query_title',
				'label' => esc_html__('Title', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__('Title', 'realite-plugin'),
			],
			[
				'name' => 'query_subtitle',
				'label' => esc_html__('Subtitle', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::TEXT
			],
			[
				'name' => 'query_category',
				'label' => esc_html__('Category', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => $media_categories,
				'multiple' => true
			],
			[
				'name' => 'query_url',
				'label' => esc_html__('URL', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::URL
			],
			[
				'name' => 'query_description',
				'label' => esc_html__('Description', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::TEXTAREA
			],
			[
				'name' => 'query_column',
				'label' => esc_html__('Column', 'realite-plugin'),
				'description' => esc_html__('Select the column of metro.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'1-column' => esc_attr__('1 Column', 'realite-plugin'),
					'2-column' => esc_attr__('2 Column', 'realite-plugin'),
					'3-column' => esc_attr__('3 Column', 'realite-plugin'),
					'4-column' => esc_attr__('4 Column', 'realite-plugin'),
					'5-column' => esc_attr__('5 Column', 'realite-plugin'),
					'6-column' => esc_attr__('6 Column', 'realite-plugin'),
					'7-column' => esc_attr__('7 Column', 'realite-plugin'),
					'8-column' => esc_attr__('8 Column', 'realite-plugin'),
					'9-column' => esc_attr__('9 Column', 'realite-plugin'),
					'10-column' => esc_attr__('10 Column', 'realite-plugin'),
					'11-column' => esc_attr__('11 Column', 'realite-plugin'),
					'12-column' => esc_attr__('12 Column', 'realite-plugin')
				],
				'default' => '3-column'
			]
		],
		'title_field' => '{{{ query_title }}}',
		'condition' => [
			'gallery_images_layout_type' => 'metro'
		]
	]
);