<?php
/**
 * Gallery Images > Content Options > Layout
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

$this->add_responsive_control(
	'gallery_images_columns',
	[
		'label' => esc_html__('Columns', 'realite-plugin'),
		'description' => esc_html__('Select the columns of the isotope grid.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'1-column'			 	=> esc_html__('1 Column', 'realite-plugin'),
			'2-columns'			 	=> esc_html__('2 Columns', 'realite-plugin'),
			'3-columns'			 	=> esc_html__('3 Columns', 'realite-plugin'),
			'4-columns'			 	=> esc_html__('4 Columns', 'realite-plugin'),
			'5-columns'			 	=> esc_html__('5 Columns', 'realite-plugin'),
			'6-columns'			 	=> esc_html__('6 Columns', 'realite-plugin')
		],
		'default' => '3-columns',
		'tablet_default' => '2-columns',
		'mobile_default' => '1-column',
		'conditions' => [
			'relation' => 'and',
			'terms' => [
				[
					'name' => 'gallery_images_layout',
					'operator' => '!=',
					'value' => 'carousel'
				],
				[
					'name' => 'gallery_images_layout_type',
					'operator' => '!==',
					'value' => 'metro',
				],
				[
					'name' => 'gallery_images_layout_type',
					'operator' => '!==',
					'value' => 'justified',
				],
			]
		]
	]
);

$this->add_control(
	'gallery_images_animation',
	[
		'label' => esc_html__('Animation', 'realite-plugin'),
		'description' => esc_html__('Select initial loading animation for posts.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'none' 				 	=> esc_html__('None', 'realite-plugin'),
			'gsFadeIn'	 	=> esc_html__('Fade In', 'realite-plugin'),
			'gsFadeInUp' 	  	=> esc_html__('Fade In Up', 'realite-plugin'),
			'gsFadeInLeft'  	=> esc_html__('Fade In Left', 'realite-plugin'),
			'gsFadeInRight' 	=> esc_html__('Fade In Right', 'realite-plugin'),
			'gsZoomIn' 	 	=> esc_html__('Zoom In', 'realite-plugin'),
			'gsPreserve3d' 	=> esc_html__('Preserve 3d', 'realite-plugin')
		],
		'default' => 'gsFadeIn',
	]
);

$this->add_control(
	'gallery_images_animation_delay',
	[
		'label' => esc_html__('Animation Delay', 'realite-plugin'),
		'description' => esc_html__('Activate the delay effect on posts.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'return_value' => 'yes',
		'default' => 'no',
		'condition' => [
			'gallery_images_animation!' => 'none'
		]
	]
);

$this->add_control(
	'gallery_images_frames',
	[
		'label' => esc_html__('Browser Frame', 'realite-plugin'),
		'description' => esc_html__('Add browser frame on gallery images', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'return_value' => 'yes',
		'default' => 'no',
		'conditions' => [
			'relation' => 'and',
			'terms' => [
				[
					'name' => 'gallery_images_layout_type',
					'operator' => '!=',
					'value' => 'justified'
				],
			],
		]
	]
);

$this->add_responsive_control(
	'gallery_images_spacing',
	[
		'label' => esc_html__('Spacing', 'realite-plugin'),
		'description' => __('Move the slider to set the value of spacing. <br /><small>Note: The value is represented in pixels.</small>', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SLIDER,
		'conditions' => [
			'terms' => [
				[
					'name' => 'gallery_images_layout',
					'operator' => '==',
					'value' => 'isotope',
				],
				[
					'name' => 'gallery_images_layout_type',
					'operator' => '!=',
					'value' => 'justified',
				],
			],
		],
		'size_units' => ['px', 'rem', '%'],
		'range' => [
			'px' => [
				'min' => 0,
				'max' => 200,
				'step' => 1,
			],
		],
		'condition' => [
			'gallery_images_layout' => 'isotope'
		],
		'selectors' => [
			'{{WRAPPER}} .isotope-container' => 'margin-left: calc(-{{SIZE}}{{UNIT}} / 2); margin-right: calc(-{{SIZE}}{{UNIT}} / 2)',
			'{{WRAPPER}} .isotope-container .iso-item' => 'padding-left: calc({{SIZE}}{{UNIT}} / 2); padding-right: calc({{SIZE}}{{UNIT}} / 2);  margin-bottom: {{SIZE}}{{UNIT}};'
		],
		'render_type' => 'template'
	]
);