<?php
/**
 * Portfolio > Style Options > Hover
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

$this->add_control(
	'portfolio_hover_visibility',
	[
		'label' => esc_html__('Visibility', 'realite-plugin'),
		'description' => esc_html__('Select the visibility of the hover.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'show'	=> esc_html__('Show', 'realite-plugin'),
			'hide'	=> esc_html__('Hide', 'realite-plugin')
		],
		'default' => 'show',
	]
);

$this->add_control(
	'portfolio_style_hover_active',
	[
		'label' => esc_html__('Active Hover', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'label_on' => esc_html__('On', 'realite-plugin'),
		'label_off' => esc_html__('Off', 'realite-plugin'),
		'return_value' => 'yes',
		'default' => 'no'
	]
);

$this->add_group_control(
	\Elementor\Group_Control_Background::get_type(),
	[
		'name' => 'portfolio_style_hover_background_type',
		'label' => esc_html__('Background', 'realite-plugin'),
		'types' => ['classic', 'gradient'],
		'selector' => '{{WRAPPER}} .gs-portfolio-list .gs-portfolio-item .entry-overlay-wrapper .entry-thumbnail__overlay',
		'separator' => 'before'
	]
);

$this->add_responsive_control(
	'portfolio_style_hover_spacing',
	[
		'label' => esc_html__('Spacing', 'realite-plugin'),
		'size_units' => ['px', 'em', '%'],
		'devices' => ['desktop', 'tablet', 'mobile'],
		'type' => Controls_Manager::DIMENSIONS,
		'selectors' => [
			'{{WRAPPER}} .gs-portfolio-list .gs-portfolio-item .entry-overlay-wrapper .entry-thumbnail__overlay' => 'top: {{TOP}}{{UNIT}}; right: {{RIGHT}}{{UNIT}}; bottom: {{BOTTOM}}{{UNIT}}; left: {{LEFT}}{{UNIT}}',
		]
	]
);

$this->add_control(
	'portfolio_style_hover_meta_vertical_alignment',
	[
		'label' => esc_html__('Meta Vertical Alignment', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::CHOOSE,
		'options' => [
			'start' => [
				'title' => esc_html__('Top', 'realite-plugin'),
				'icon' => 'eicon-v-align-top'
			],
			'center' => [
				'title' => esc_html__('Middle', 'realite-plugin'),
				'icon' => 'eicon-v-align-middle'
			],
			'end' => [
				'title' => esc_html__('Bottom', 'realite-plugin'),
				'icon' => 'eicon-v-align-bottom'
			]
		],
		'conditions' => [
			'terms' => [
				[
					'name' => 'portfolio_layout_model',
					'operator' => '==',
					'value' => 'meta-overlay'
				]
			]
		],
		'separator' => 'before'
	]
);

$this->add_control(
	'portfolio_style_hover_button',
	[
		'label' => esc_html__('Button', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'label_on' => esc_html__('Show', 'realite-plugin'),
		'label_off' => esc_html__('Hide', 'realite-plugin'),
		'return_value' => 'yes',
		'default' => 'yes',
		'separator' => 'before',
		'conditions' =>  [
			'terms' => [
				[
					'name' => 'portfolio_layout_model',
					'operator' => '==',
					'value' => 'meta-overlay'
				],
			]
		]
	]
);

$this->add_control(
	'portfolio_style_hover_button_color',
	[
		'label' => esc_html__('Button Color', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::COLOR,
		'selectors' => [
			'{{WRAPPER}} .gs-portfolio-list .gs-portfolio-item .entry-overlay-wrapper > a' => 'color: {{VALUE}} !important'
		],
		'conditions' =>  [
			'terms' => [
				[
					'name' => 'portfolio_style_hover_button',
					'operator' => '==',
					'value' => 'yes'
				],
			]
		]
	]
);