<?php
/**
 * Posts > Content Options > Layout
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

$this->add_responsive_control(
	'products_columns',
	[
		'label' => esc_html__('Columns', 'realite-plugin'),
		'description' => esc_html__('Select the columns of the isotope grid.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'1-column'			 	=> esc_html__('1 Column', 'realite-plugin'),
			'2-columns'			 	=> esc_html__('2 Columns', 'realite-plugin'),
			'3-columns'			 	=> esc_html__('3 Columns', 'realite-plugin'),
			'4-columns'			 	=> esc_html__('4 Columns', 'realite-plugin'),
			'5-columns'			 	=> esc_html__('5 Columns', 'realite-plugin'),
			'6-columns'			 	=> esc_html__('6 Columns', 'realite-plugin')
		],
		'default' => '3-columns',
		'tablet_default' => '2-columns',
		'mobile_default' => '1-column',
		'conditions' => [
			'terms' => [
				[
					'name' => 'products_layout',
					'operator' => '==',
					'value' => 'isotope',
				],
				[
					'name' => 'products_layout_type',
					'operator' => '!=',
					'value' => 'justified',
				],
				[
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'products_layout',
							'operator' => '==',
							'value' => 'carousel'
						],
						[
							'name' => 'products_layout_type',
							'operator' => '!==',
							'value' => 'metro',
						],
					]
				]
			],
		]
	]
);

$this->add_control(
	'products_animation',
	[
		'label' => esc_html__('Animation', 'realite-plugin'),
		'description' => esc_html__('Select initial loading animation for posts.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'options' => [
			'none' 				 	=> esc_html__('None', 'realite-plugin'),
			'gsFadeIn'	 	=> esc_html__('Fade In', 'realite-plugin'),
			'gsFadeInUp' 	  	=> esc_html__('Fade In Up', 'realite-plugin'),
			'gsFadeInLeft'  	=> esc_html__('Fade In Left', 'realite-plugin'),
			'gsFadeInRight' 	=> esc_html__('Fade In Right', 'realite-plugin'),
			'gsZoomIn' 	 	=> esc_html__('Zoom In', 'realite-plugin'),
			'gsZoomOut' 	 	=> esc_html__('Zoom Out', 'realite-plugin'),
			'gsPreserve3d' 	=> esc_html__('Preserve 3d', 'realite-plugin')
		],
		'default' => 'gsFadeIn',
	]
);

$this->add_control(
	'products_animation_delay',
	[
		'label' => esc_html__('Animation Delay', 'realite-plugin'),
		'description' => esc_html__('Activate the delay effect on posts.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'return_value' => 'yes',
		'default' => 'no',
		'condition' => [
			'products_animation!' => 'none'
		]
	]
);

$this->add_control(
	'products_offset',
	[
		'label' => esc_html__('Offset', 'realite-plugin'),
		'description' => esc_html__('Activate an offset layout which will set spacing every second post.', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SWITCHER,
		'return_value' => 'yes',
		'default' => 'no',
		'prefix_class' => 'h-offset--',
		'conditions' => [
			'terms' => [
				[
					'name' => 'products_layout',
					'operator' => '==',
					'value' => 'isotope',
				],
				[
					'name' => 'products_layout_type',
					'operator' => '!=',
					'value' => 'metro',
				],
				[
					'name' => 'products_layout_type',
					'operator' => '!=',
					'value' => 'justified',
				],
			],
		]
	]
);

$this->add_responsive_control(
	'products_spacing',
	[
		'label' => esc_html__('Spacing', 'realite-plugin'),
		'description' => __('Move the slider to set the value of spacing. <br /><small>Note: The value is represented in pixels.</small>', 'realite-plugin'),
		'type' => \Elementor\Controls_Manager::SLIDER,
		'condition' => [
			'products_layout' => 'isotope',
			'products_layout_type!' => 'justified'
		],
		'size_units' => ['px', 'rem', '%'],
		'range' => [
			'px' => [
				'min' => 0,
				'max' => 200,
				'step' => 1,
			],
		],
		'selectors' => [
			'{{WRAPPER}} .isotope-container' => 'margin-left: calc(-{{SIZE}}{{UNIT}} / 2); margin-right: calc(-{{SIZE}}{{UNIT}} / 2)',
			'{{WRAPPER}} .isotope-container .iso-item' => 'padding-left: calc({{SIZE}}{{UNIT}} / 2); padding-right: calc({{SIZE}}{{UNIT}} / 2); margin-bottom: {{SIZE}}{{UNIT}} !important;',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="2-columns"]:nth-child(2)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="3-columns"]:nth-child(1)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="3-columns"]:nth-child(3)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="4-columns"]:nth-child(1)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="4-columns"]:nth-child(3)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="5-columns"]:nth-child(1)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="5-columns"]:nth-child(3)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="5-columns"]:nth-child(5)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="6-columns"]:nth-child(1)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="6-columns"]:nth-child(3)' => 'margin-top: {{SIZE}}{{UNIT}} !important',
			'{{WRAPPER}}.h-offset--yes .iso-item[data-col-num="6-columns"]:nth-child(5)' => 'margin-top: {{SIZE}}{{UNIT}} !important'
		],
		'render_type' => 'template'
	]
);