<?php
namespace GradaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if (!class_exists('WooCommerce')) {
	return;
}

/**
 * @since 1.0.0
 */
class GradaMenuCart extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'grada-menu-cart';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__('Menu Cart', 'realite-plugin');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-cart-light grada-badge';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return ['grada-site-category'];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'menu_cart_functionality',
			[
				'label' => esc_html__('Functionality', 'realite-plugin'),
			]
		);

		$this->add_control(
			'menu_cart_raw',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => esc_html__('Do not forget to select the cart page at WooCommerce > Settings > Advanced.', 'realite-plugin'),
				'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
			]
		);

		$this->add_control(
			'menu_cart_alignment',
			[
				'label' => esc_html__('Alignment', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => esc_html__('Left', 'realite-plugin'),
						'icon' => 'fa fa-align-left'
					],
					'center' => [
						'title' => esc_html__('Center', 'realite-plugin'),
						'icon' => 'fa fa-align-center'
					],
					'end' => [
						'title' => esc_html__('Right', 'realite-plugin'),
						'icon' => 'fa fa-align-right'
					],
				],
				'label_block' => false,
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart-holder' => 'justify-content: flex-{{VALUE}} !important; -webkit-box-pack: {{VALUE}} !important; -ms-flex-pack: {{VALUE}} !important;'
				],
				'default' => 'start'
			]
		);

		$this->add_control(
			'menu_cart_color',
			[
				'label' => esc_html__('Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart-icon' => 'color: {{VALUE}} !important',
				]
			]
		);

		$this->add_responsive_control(
			'menu_cart_size',
			[
				'label' => esc_html__('Size', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px', '%', 'vw'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 1
					]
				],
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart-icon svg' => 'width: {{SIZE}}{{UNIT}} !important; height: {{SIZE}}{{UNIT}} !important',
				]
			]
		);

		$this->add_control(
			'menu_cart_content',
			[
				'label' => esc_html__('Hide Cart Content', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'no',
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart .dropdown-cart' => 'display: none !important',
				]
			]
		);

		$this->add_control(
			'menu_cart_badge_heading',
			[
				'label' => esc_html__('Badge', 'realite-plugin'),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before'
			]
		);

		$this->add_control(
			'menu_cart_badge_color',
			[
				'label' => esc_html__('Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart .header-shopping-cart-icon span' => 'color: {{VALUE}} !important',
				]
			]
		);

		$this->add_control(
			'menu_cart_badge_background_color',
			[
				'label' => esc_html__('Background Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart .header-shopping-cart-icon span' => 'background-color: {{VALUE}} !important',
				]
			]
		);

		$this->add_responsive_control(
			'menu_cart_badge_size',
			[
				'label' => esc_html__('Size', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px', '%', 'vw'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 1
					]
				],
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart-icon span.number' => 'width: {{SIZE}}{{UNIT}} !important; height: {{SIZE}}{{UNIT}} !important; line-height: {{SIZE}}{{UNIT}} !important',
				]
			]
		);

		$this->add_responsive_control(
			'menu_cart_badge_number',
			[
				'label' => esc_html__('Number', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px', '%', 'vw'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 1
					]
				],
				'selectors' => [
					'{{WRAPPER}} .header-shopping-cart-icon span.number' => 'font-size: {{SIZE}}{{UNIT}} !important',
				]
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<div class="header-shopping-cart-holder d-flex justify-content-center">
			<div class="header-shopping-cart d-inline-flex">
				<a class="header-shopping-cart-icon" href="<?php echo esc_url(wc_get_cart_url()) ?>">
					<svg enable-background="new 0 0 512 512" viewBox="0 0 512 512" xmlns="http://www.w3.org/2000/svg" width="20" height="20"><path d="m467.952 427.383-25.3-245.673c-1.045-10.187-9.627-17.93-19.867-17.93h-332.9c-10.213 0-18.789 7.717-19.861 17.877l-25.98 245.793c-2.144 21.452 5.007 43.011 19.614 59.156 14.608 16.133 35.328 25.394 56.853 25.394h271.653c21.425 0 41.952-9.075 56.293-24.914 14.542-16.026 21.646-37.758 19.495-59.703zm-49.076 32.878c-6.898 7.603-16.385 11.791-26.712 11.791h-271.646c-10.26 0-20.187-4.468-27.238-12.257-7.051-7.79-10.506-18.13-9.494-28.257l24.075-227.803h296.9l23.449 227.657c1.066 10.806-2.257 21.059-9.334 28.869z"></path><path d="m259.663 0c-63.144 0-114.518 51.373-114.518 114.518v69.243h39.948v-69.243c0-41.12 33.45-74.57 74.57-74.57s74.576 33.45 74.576 74.57v69.243h39.941v-69.243c.001-63.145-51.372-114.518-114.517-114.518z"></path></svg>
					<span class="cart-number">
						<?php
						if (isset(WC()->cart->cart_contents_count)) {
							echo sprintf('%d', WC()->cart->cart_contents_count);
						} elseif (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
							echo 0;
						}
						?>
					</span>
				</a>
                <div class="dropdown-cart">
                    <div class="dropdown-shopping-cart widget_shopping_cart_content"></div>
                </div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}
