<?php
namespace GradaElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.0.0
 */
class GradaTestimonialCarousel extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'grada-testimonial-carousel';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__('Testimonial Carousel', 'realite-plugin');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial-carousel grada-badge';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return ['grada-category'];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'slides_section',
			[
				'label' => esc_html__('Slides', 'realite-plugin'),
			]
		);

		$this->add_control(
			'slides',
			[
				'label' => esc_html__('Slides', 'realite-plugin'),
				'description' => esc_html__('Add slides to the testimonial carousel.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'content',
						'label' => esc_html__('Content', 'realite-plugin'),
						'type' => \Elementor\Controls_Manager::TEXTAREA,
						'default' => esc_html__('I am slide content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'realite-plugin')
					],
					[
						'name' => 'image',
						'label' => esc_html__('Image', 'realite-plugin'),
						'type' => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => get_template_directory_uri() . '/assets/images/placeholder.png'
						],
					],
					[
						'name' => 'name',
						'label' => esc_html__('Name', 'realite-plugin'),
						'type' => \Elementor\Controls_Manager::TEXT,
						'default' => esc_html__('John Doe', 'realite-plugin')
					],
					[
						'name' => 'title',
						'label' => esc_html__('Title', 'realite-plugin'),
						'type' => \Elementor\Controls_Manager::TEXT,
						'default' => esc_html__('Developer', 'realite-plugin')
					],
				],
				'default' => [
					[
						'content' => esc_html__('I am slide content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'realite-plugin'),
						'name' => esc_html__('John Doe', 'realite-plugin'),
						'title' => esc_html__('Developer', 'realite-plugin'),
						'image' => [
							'url' => get_template_directory_uri() . '/assets/images/placeholder.png'
						],
					],
					[
						'content' => esc_html__('I am slide content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'realite-plugin'),
						'name' => esc_html__('Chris Parker', 'realite-plugin'),
						'title' => esc_html__('Designer', 'realite-plugin'),
						'image' => [
							'url' => get_template_directory_uri() . '/assets/images/placeholder.png'
						],
					],
					[
						'content' => esc_html__('I am slide content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'realite-plugin'),
						'name' => esc_html__('Peter Jack', 'realite-plugin'),
						'title' => esc_html__('CEO', 'realite-plugin'),
						'image' => [
							'url' => get_template_directory_uri() . '/assets/images/placeholder.png'
						],
					],
				],
			]
		);

		$this->add_control(
			'layout',
			[
				'label' => esc_html__('Layout', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'image-inline' => esc_html__('Image Inline', 'realite-plugin'),
					'image-stacked' => esc_html__('Image Stacked', 'realite-plugin'),
					'image-above' => esc_html__('Image Above', 'realite-plugin'),
					'image-left' => esc_html__('Image Left', 'realite-plugin'),
					'image-right' => esc_html__('Image Right', 'realite-plugin'),
				],
				'default' => 'image-inline',
				'render_type' => 'template',
				'prefix_class' => 'gs-testimonial-list-'
			]
		);

		$this->add_control(
			'alignment',
			[
				'label' => esc_html__('Alignment', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label_block' => false,
				'default' => 'center',
				'options' => [
					'left' => [
						'title' => esc_html__('Left', 'realite-plugin'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'realite-plugin'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'realite-plugin'),
						'icon' => 'fa fa-align-right',
					],
				],
				'prefix_class' => 'testimonials-content-'
			]
		);

		$this->add_responsive_control(
			'columns',
			[
				'label' => __('Columns', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'1' => __('1 Column', 'realite-plugin'),
					'2' => __('2 Columns', 'realite-plugin'),
					'3' => __('3 Columns', 'realite-plugin'),
					'4' => __('4 Columns', 'realite-plugin'),
					'5' => __('5 Columns', 'realite-plugin'),
					'6' => __('6 Columns', 'realite-plugin')
				],
				'default' => '1'
			]
		);

		$this->add_control(
			'animation',
			[
				'label' => __('Animation', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' 				 	=> __('None', 'realite-plugin'),
					'gsFadeIn'	 	=> __('Fade In', 'realite-plugin'),
					'gsFadeInUp' 	  	=> __('Fade In Up', 'realite-plugin'),
					'gsFadeInLeft'  	=> __('Fade In Left', 'realite-plugin'),
					'gsFadeInRight' 	=> __('Fade In Right', 'realite-plugin'),
					'gsZoomIn' 	 	=> __('Zoom In', 'realite-plugin'),
					'gsZoomOut' 	 	=> __('Zoom Out', 'realite-plugin'),
					'gsPreserve3d' 	=> __('Preserve 3d', 'realite-plugin')
				],
				'default' => 'gsFadeIn',
			]
		);

		$this->add_control(
			'animation_delay',
			[
				'label' => __('Animation Delay', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'animation!' => 'none'
				]
			]
		);

		$this->add_responsive_control(
			'width',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => __('Width', 'realite-plugin'),
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 1300,
					],
					'%' => [
						'min' => 50,
					],
				],
				'size_units' => ['%', 'px'],
				'default' => [
					'size' => 100,
					'unit' => '%',
				],
				'selectors' => [
					'{{WRAPPER}} .owl-item .gs-testimonial-item' => 'width: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'carousel',
			[
				'label' => __('Carousel', 'realite-plugin')
			]
		);

		$this->add_responsive_control(
			'carousel_margin',
			[
				'label' => __('Margin', 'realite-plugin'),
				'description' => __('Enter the margin space, number will be represented in pixels.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 10,
				'min'     => 0,
				'max'     => 100,
				'step'    => 1
			]
		);

		$this->add_control(
			'carousel_auto_height',
			[
				'label' => __('Auto Height', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'1' => __('On', 'realite-plugin'),
					'2' => __('Off', 'realite-plugin'),
				],
				'default' => '1'
			]
		);

		$this->add_control(
			'carousel_loop',
			[
				'label' => __('Loop', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('On', 'realite-plugin'),
				'label_off' => __('Off', 'realite-plugin'),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'carousel_mouse_drag',
			[
				'label' => __('Mouse Drag', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('On', 'realite-plugin'),
				'label_off' => __('Off', 'realite-plugin'),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'carousel_touch_drag',
			[
				'label' => __('Touch Drag', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('On', 'realite-plugin'),
				'label_off' => __('Off', 'realite-plugin'),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'carousel_navigation',
			[
				'label' => __('Navigation', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('On', 'realite-plugin'),
				'label_off' => __('Off', 'realite-plugin'),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'carousel_dots',
			[
				'label' => __('Dots', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('On', 'realite-plugin'),
				'label_off' => __('Off', 'realite-plugin'),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'carousel_autoplay',
			[
				'label' => __('Autoplay', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('On', 'realite-plugin'),
				'label_off' => __('Off', 'realite-plugin'),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'carousel_pause',
			[
				'label' => __('Pause on mouse house', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('On', 'realite-plugin'),
				'label_off' => __('Off', 'realite-plugin'),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_responsive_control(
			'carousel_stage_padding',
			[
				'label' => __('Stage Padding', 'realite-plugin'),
				'description' => __('Padding left and right on stage (can see neighbours).', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 0,
				'min'     => 0,
				'max'     => 500,
				'step'    => 1
			]
		);

		$this->add_control(
			'carousel_start_position',
			[
				'label' => __('Start Position', 'realite-plugin'),
				'description' => __('Enter from which element you want to start the position of carousel.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 0,
				'min'     => 0,
				'max'     => 500,
				'step'    => 1
			]
		);

		$this->add_control(
			'carousel_autoplay_timeout',
			[
				'label' => __('Auto Play Timeout', 'realite-plugin'),
				'description' => __('Autoplay interval timeout, number is represented in seconds.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 2,
				'min'     => 0,
				'max'     => 500,
				'step'    => 0.1
			]
		);

		$this->add_control(
			'carousel_smart_speed',
			[
				'label' => __('Smart Speed', 'realite-plugin'),
				'description' => __('Speed Calculate, number is represented in seconds.', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 4.5,
				'min'     => 0,
				'max'     => 500,
				'step'    => 0.1
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slides_section_style',
			[
				'label' => __('Slides', 'realite-plugin'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'slide_background_color',
			[
				'label' => __('Background Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gs-testimonial-item' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'slide_border_type',
			[
				'label' => __('Border Type', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => __('None', 'realite-plugin'),
					'solid' => __('Solid', 'realite-plugin'),
					'double' => __('Double', 'realite-plugin'),
					'dotted' => __('Dotted', 'realite-plugin'),
					'dashed' => __('Dashed', 'realite-plugin'),
					'groove' => __('Groove', 'realite-plugin')
				],
				'default' => 'none',
				'selectors' => [
					'{{WRAPPER}} .gs-testimonial-item' => 'border-style: {{VALUE}}'
				],
			]
		);

		$this->add_responsive_control(
			'slide_border_size',
			[
				'label' => __('Border Size', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'selectors' => [
					'{{WRAPPER}} .gs-testimonial-item' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
				'condition' => [
					'slide_border_type!' => 'none'
				]
			]
		);

		$this->add_control(
			'slide_border_color',
			[
				'label' => __('Border Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gs-testimonial-item' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'slide_border_type!' => 'none'
				]
			]
		);


		$this->add_responsive_control(
			'slide_border_radius',
			[
				'label' => __('Border Radius', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'%' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .gs-testimonial-item' => 'border-radius: {{SIZE}}{{UNIT}}',
				],
				'condition' => [
					'slide_border_type!' => 'none'
				]
			]
		);

		$this->add_responsive_control(
			'slide_padding',
			[
				'label' => __('Padding', 'realite-plugin'),
				'size_units' => ['px', 'rem', '%'],
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'selectors' => [
					'{{WRAPPER}} .gs-testimonial-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_style',
			[
				'label' => __('Content', 'realite-plugin'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'content_gap',
			[
				'label' => __('Gap', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}}.gs-testimonial-list-image-inline .testimonial-body' => 'margin-bottom: {{SIZE}}{{UNIT}}',
					'{{WRAPPER}}.gs-testimonial-list-image-stacked .testimonial-body' => 'margin-bottom: {{SIZE}}{{UNIT}}',
					'{{WRAPPER}}.gs-testimonial-list-image-right .testimonial-body' => 'padding-right: {{SIZE}}{{UNIT}}',
					'{{WRAPPER}}.gs-testimonial-list-image-left .testimonial-body' => 'padding-left: {{SIZE}}{{UNIT}}',
					'{{WRAPPER}}.gs-testimonial-list-image-above .testimonial-body' => 'margin-top: {{SIZE}}{{UNIT}}'
				],
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' => __('Text Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-text' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} .testimonial-text',
			]
		);

		$this->add_control(
			'name_title_style',
			[
				'label' => __('Name', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label' => __('Text Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-author-name' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'name_typography',
				'selector' => '{{WRAPPER}} .testimonial-author-name',
			]
		);

		$this->add_control(
			'heading_title_style',
			[
				'label' => __('Title', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __('Text Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-author-job' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .testimonial-author-job',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_image_style',
			[
				'label' => __('Image', 'realite-plugin'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'image_size',
			[
				'label' => __('Size', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .testimonial-avatar' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};'
				],
			]
		);

		$this->add_control(
			'image_border_size',
			[
				'label' => __('Border Size', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .testimonial-avatar img' => 'border-width: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_control(
			'image_border_type',
			[
				'label' => __('Border Type', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => __('None', 'realite-plugin'),
					'solid' => __('Solid', 'realite-plugin'),
					'double' => __('Double', 'realite-plugin'),
					'dotted' => __('Dotted', 'realite-plugin'),
					'dashed' => __('Dashed', 'realite-plugin'),
					'groove' => __('Groove', 'realite-plugin')
				],
				'default' => 'none',
				'selectors' => [
					'{{WRAPPER}} .testimonial-avatar img' => 'border-style: {{VALUE}}'
				],
			]
		);

		$this->add_control(
			'image_border_radius',
			[
				'label' => __('Border Radius', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'%' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .testimonial-avatar img' => 'border-radius: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_control(
			'image_border_color',
			[
				'label' => __('Border Color', 'realite-plugin'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-avatar img' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$testimonial_id = 'testimonial-carousel-' . uniqid();

		/**
		 * Animation & WOW Delay
		 */
		$grada_data_wow_delay = false;
		$grada_data_wow_seconds = 0;
		$grada_slider_class = 'wow gs-testimonial-item';

		if ($settings['animation'] != 'none') {
			if ($settings['animation_delay'] == 'yes' && !\Elementor\Plugin::$instance->editor->is_edit_mode()) {
				$grada_data_wow_delay = true;
				$grada_slider_class .= $settings['carousel_stage_padding'] ? ' wow ' . $settings['animation'] : ' wow init-anim';
			} elseif ($settings['animation_delay'] != 'yes') {
				$grada_slider_class .= ' wow ' . $settings['animation'];
			}
		}
		?>
		<div class="owl-carousel owl-theme" id="<?php echo esc_attr( $testimonial_id ); ?>" data-animation="<?php echo esc_attr($settings['animation']) ?>" data-wow="<?php echo esc_attr($settings['animation_delay']) ?>">
			<?php foreach ($settings['slides'] as $slide) : ?>
				<?php
				/**
				 * WOW Animation
				 */
				if ($grada_data_wow_seconds == 6) {
					$grada_data_wow_seconds = 0;
				}
				$grada_wow_holder = "data-wow-delay=". $grada_data_wow_seconds / 10 ."s";
				?>
				<div class="<?php echo esc_attr($grada_slider_class) ?>" <?php echo esc_attr($grada_data_wow_delay === true && $grada_data_wow_seconds ? $grada_wow_holder : '') ?>>
					<?php if ($slide['image']['url'] && $settings['layout'] == 'image-above') : ?>
						<div class="testimonial-avatar">
							<img src="<?php echo esc_url($slide['image']['url']) ?>" alt="<?php echo esc_attr($slide['name']) ?>">
						</div>
					<?php endif; ?>
					<?php if ($slide['content']) : ?>
						<div class="testimonial-body">
							<?php if ($slide['content']) : ?>
								<div class="testimonial-text"><?php echo wp_kses_post($slide['content']) ?></div>
							<?php endif; ?>
							<?php if ($settings['layout'] == 'image-left' || $settings['layout'] == 'image-right') : ?>
								<div class="testimonial-author">
									<?php if ($slide['name']) : ?>
										<span class="testimonial-author-name"><?php echo esc_attr($slide['name']) ?></span>
									<?php endif; ?>
									<?php if ($slide['title']) : ?>
										<span class="testimonial-author-job"><?php echo esc_attr($slide['title']) ?></span>
									<?php endif; ?>
								</div>
							<?php endif; ?>
						</div>
					<?php endif; ?>
					<div class="testimonial-bottom">
						<?php if ($slide['image']['url'] && $settings['layout'] != 'image-above') : ?>
							<div class="testimonial-avatar">
								<img src="<?php echo esc_url($slide['image']['url']) ?>" alt="<?php echo esc_attr($slide['name']) ?>">
							</div>
						<?php endif; ?>
						<?php if ($settings['layout'] != 'image-left' && $settings['layout'] != 'image-right') : ?>
							<div class="testimonial-author">
								<?php if ($slide['name']) : ?>
									<span class="testimonial-author-name"><?php echo esc_attr($slide['name']) ?></span>
								<?php endif; ?>
								<?php if ($slide['title']) : ?>
									<span class="testimonial-author-job"><?php echo esc_attr($slide['title']) ?></span>
								<?php endif; ?>
							</div>
						<?php endif; ?>
					</div>
				</div>
				<?php $grada_data_wow_seconds = $grada_data_wow_seconds + 2; endforeach; ?>
		</div>
		<script type="text/javascript">
            jQuery(function ($) {
                var owl = $('#<?php echo esc_attr( $testimonial_id ); ?>');

                owl.owlCarousel({
                    items: <?php echo esc_attr($settings['columns_mobile'] ? $settings['columns_mobile'] : '1') ?>,
                    margin: <?php echo esc_attr($settings['carousel_margin_mobile'] ? $settings['carousel_margin_mobile'] : '10') ?>,
                    autoHeight: <?php echo esc_attr($settings['carousel_auto_height'] == '1' ? 'true' : 'false') ?>,
                    loop: <?php echo esc_attr($settings['carousel_loop'] === 'yes' ? 'true' : 'false') ?>,
                    mouseDrag: <?php echo esc_attr($settings['carousel_mouse_drag'] === 'yes' ? 'true' : 'false') ?>,
                    touchDrag: <?php echo esc_attr($settings['carousel_touch_drag'] === 'yes' ? 'true' : 'false') ?>,
                    stagePadding: <?php echo esc_attr($settings['carousel_stage_padding_mobile'] ? $settings['carousel_stage_padding_mobile'] : '0') ?>,
                    startPosition: <?php echo esc_attr($settings['carousel_start_position'] ? $settings['carousel_start_position'] : '0') ?>,
                    nav: <?php echo esc_attr($settings['carousel_navigation'] === 'yes' ? 'true' : 'false') ?>,
                    navText: [
                        '<svg width="20" height="20" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M19 12H5" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/><path d="M12 19L5 12L12 5" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/></svg>',
                        '<svg width="20" height="20" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M5 12H19" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/><path d="M12 5L19 12L12 19" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/></svg>',
                    ],
                    dots: <?php echo esc_attr($settings['carousel_dots'] === 'yes' ? 'true' : 'false') ?>,
                    autoplay: <?php echo esc_attr($settings['carousel_autoplay'] === 'yes' ? 'true' : 'false') ?>,
                    autoplayTimeout: <?php echo esc_attr($settings['carousel_autoplay_timeout'] ? $settings['carousel_autoplay_timeout'] * 1000 : '2000') ?>,
                    autoplayHoverPause: <?php echo esc_attr($settings['carousel_pause'] === 'yes' ? 'true' : 'false') ?>,
                    smartSpeed: <?php echo esc_attr($settings['carousel_smart_speed'] ? $settings['carousel_smart_speed'] * 100 : '450') ?>,
                    responsive:{
                        768:{
                            items: <?php echo esc_attr($settings['columns_tablet'] ? $settings['columns_tablet'] : '1') ?>,
                            margin: <?php echo esc_attr($settings['carousel_margin_tablet'] ? $settings['carousel_margin_tablet'] : '5') ?>,
                            stagePadding: <?php echo esc_attr($settings['carousel_stage_padding_tablet'] ? $settings['carousel_stage_padding_tablet'] : '0') ?>
                        },
                        992:{
                            items: <?php echo esc_attr($settings['columns'] ? $settings['columns'] : '1') ?>,
                            margin: <?php echo esc_attr($settings['carousel_margin'] ? $settings['carousel_margin'] : '0') ?>,
                            stagePadding: <?php echo esc_attr($settings['carousel_stage_padding'] ? $settings['carousel_stage_padding'] : '0') ?>
                        }
                    }
                });
            });
		</script>
		<?php
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}
