<?php
/**
 * Footer Options
 */

// Create Panel and Sections
Kirki::add_panel('footer_options', array(
	'title'       => esc_html__('Footer', 'realite-plugin'),
	'priority'    => 3
));
Kirki::add_section('footer_general_section', array(
	'title'          => esc_html__('General', 'realite-plugin'),
	'priority'       => 1,
	'panel'			=> 'footer_options'
));
Kirki::add_section('footer_copyright_section', array(
	'title'          => esc_html__('Copyright', 'realite-plugin'),
	'priority'       => 2,
	'panel'			=> 'footer_options'
));
Kirki::add_section('footer_widgets_section', array(
	'title'          => esc_html__('Widgets', 'realite-plugin'),
	'priority'       => 3,
	'panel'			=> 'footer_options'
));
Kirki::add_section('footer_social_media_section', array(
	'title'          => esc_html__('Social Media', 'realite-plugin'),
	'priority'       => 4,
	'panel'			=> 'footer_options'
));

// General Settings
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_type',
	'label'       => esc_html__('Type', 'realite-plugin'),
	'description' => esc_html__('Select the footer type. <br /> <small>Note: Make sure to create templates with Elementor as footer type.</small>', 'realite-plugin'),
	'section'     => 'footer_general_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('Default', 'realite-plugin'),
		'2' => esc_html__('Template', 'realite-plugin')
	),
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_template',
	'label'       => esc_html__('Template', 'realite-plugin'),
	'description' => esc_html__('Select the footer template.', 'realite-plugin'),
	'section'     => 'footer_general_section',
	'choices'     => grada_get_elementor_template('footer'),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '==',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_skin',
	'label'       => esc_html__('Skin', 'realite-plugin'),
	'description' => esc_html__('Select the footer skin, the default is dark.', 'realite-plugin'),
	'section'     => 'footer_general_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('Dark', 'realite-plugin'),
		'2' => esc_html__('Light', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_container',
	'label'       => esc_html__('Container', 'realite-plugin'),
	'description' => __('Select if you want to use container holder for the footer. <br /> <small>Note: By selecting off, the footer will push into left and right.</small>', 'realite-plugin'),
	'section'     => 'footer_general_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('On', 'realite-plugin'),
		'2' => esc_html__('Off', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_parallax',
	'label'       => esc_html__('Parallax', 'realite-plugin'),
	'description' => esc_html__('Enable a parallax effect for your footer. The footer will come smoothly in the position fixed when scrolling at the bottom.', 'realite-plugin'),
	'section'     => 'footer_general_section',
	'default'     => '2',
	'choices'     => array(
		'1' => esc_html__('On', 'realite-plugin'),
		'2' => esc_html__('Off', 'realite-plugin')
	),
));

// Copyright Settings
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_copyright_visibility',
	'label'       => esc_html__('Visibility', 'realite-plugin'),
	'description' => esc_html__('Show or hide the copyright, by hiding the copyright the social media will be hidden too.', 'realite-plugin'),
	'section'     => 'footer_copyright_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('Show', 'realite-plugin'),
		'2' => esc_html__('Hide', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'textarea',
	'settings'    => 'footer_copyright',
	'label'       => esc_html__('Copyright', 'realite-plugin'),
	'description' => esc_html__('Enter the text that will appear in footer as copyright. <small>Note: It accepts HTML tags.</small>', 'realite-plugin'),
	'section'     => 'footer_copyright_section',
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_copyright_automated',
	'label'       => esc_html__('Automated', 'realite-plugin'),
	'description' => esc_html__('Enable the automated copyright, it will work only if you don\'t add copyright in the field above.', 'realite-plugin'),
	'section'     => 'footer_copyright_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('On', 'realite-plugin'),
		'2' => esc_html__('Off', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_copyright_alignment',
	'label'       => esc_html__('Alignment', 'realite-plugin'),
	'description' => esc_html__('Select the alignment of copyright, if selected left the social media will be placed on the right and so on.', 'realite-plugin'),
	'section'     => 'footer_copyright_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('Left', 'realite-plugin'),
		'2' => esc_html__('Right', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));

// Widgets Settings
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_widgets',
	'label'       => esc_html__('Visibility', 'realite-plugin'),
	'description' => esc_html__('Show or hide the widgets on footer.', 'realite-plugin'),
	'section'     => 'footer_widgets_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('Show', 'realite-plugin'),
		'2' => esc_html__('Hide', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_widgets_columns',
	'label'       => esc_html__('Columns', 'realite-plugin'),
	'description' => esc_html__('Select the columns of widgets, default is 4 columns.', 'realite-plugin'),
	'section'     => 'footer_widgets_section',
	'default'     => '4',
	'choices'     => array(
		'1' => esc_html__('One Column', 'realite-plugin'),
		'2' => esc_html__('Two Columns', 'realite-plugin'),
		'3' => esc_html__('Three Columns', 'realite-plugin'),
		'4' => esc_html__('Four Columns', 'realite-plugin'),
		'5' => esc_html__('Five Columns', 'realite-plugin'),
		'6' => esc_html__('Six Columns', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_mobile_visibility',
	'label'       => esc_html__('Mobile Visibility', 'realite-plugin'),
	'description' => esc_html__('Select the visibility of the widgets in mobile layout mode (< 768px).', 'realite-plugin'),
	'section'     => 'footer_widgets_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('Show', 'realite-plugin'),
		'2' => esc_html__('Hide', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));

// Social Media Settings
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'footer_social_media_visibility',
	'label'       => esc_html__('Visibility', 'realite-plugin'),
	'description' => esc_html__('Show or hide the social media in footer.', 'realite-plugin'),
	'section'     => 'footer_social_media_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_html__('Show', 'realite-plugin'),
		'2' => esc_html__('Hide', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));
Kirki::add_field('grada_kirki', array(
	'type'        => 'sortable',
	'settings'    => 'footer_social_media_enabled',
	'label'       => esc_html__('Social Media', 'realite-plugin'),
	'description' => __('Select which ones you want to display as social media in footer. Click on the eye to make them visible, you can also drag & drop them. <br /><small>Note: Do not forget to add the links at Theme Options > Social Media.</small>', 'realite-plugin'),
	'section'     => 'footer_social_media_section',
	'default'     => array(
		'facebook',
		'twitter',
		'dribbble',
		'pinterest',
		'linkedin'
	),
	'choices' => array(
		'facebook' => esc_html__('Facebook', 'realite-plugin'),
		'twitter' => esc_html__('Twitter', 'realite-plugin'),
		'google_plus' => esc_html__('Google Plus', 'realite-plugin'),
		'vimeo' => esc_html__('Vimeo', 'realite-plugin'),
		'dribbble' => esc_html__('Dribbble', 'realite-plugin'),
		'pinterest' => esc_html__('Pinterest', 'realite-plugin'),
		'youtube' => esc_html__('Youtube', 'realite-plugin'),
		'tumblr' => esc_html__('Tumblr', 'realite-plugin'),
		'linkedin' => esc_html__('Linkedin', 'realite-plugin'),
		'flickr' => esc_html__('Flickr', 'realite-plugin'),
		'spotify' => esc_html__('Spotify', 'realite-plugin'),
		'instagram' => esc_html__('Instagram', 'realite-plugin'),
	),
	'active_callback' => array(
		array(
			'setting'  => 'footer_social_media_visibility',
			'operator' => '==',
			'value'    => '1'
		),
		array(
			'setting'  => 'footer_type',
			'operator' => '!=',
			'value'    => '2'
		),
	)
));