<?php
/**
 * General Options
 */

// Create Section for General Options
Kirki::add_section( 'general_section', array(
	'title'          => esc_html__('General', 'realite-plugin'),
	'priority'       => 1
));

// General Settings
Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'custom_fields_panel',
	'label'       => esc_html__('Custom Fields Panel', 'realite-plugin'),
	'description' => esc_html__('Enable or disable the custom fields panel(ACF Panel), default is disabled.', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => '2',
	'choices'     => array(
		'1' => esc_attr__('Enable', 'realite-plugin'),
		'2' => esc_attr__('Disable', 'realite-plugin')
	),
));

Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'comments_closed',
	'label'       => esc_html__('Comments Notice', 'realite-plugin'),
	'description' => esc_html__('Show or hide the notice \'Comments are Closed!\'.', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_attr__('Show', 'realite-plugin'),
		'2' => esc_attr__('Hide', 'realite-plugin')
	),
));

Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'body_offset',
	'label'       => esc_html__('Body Offset', 'realite-plugin'),
	'description' => __('Create a left or right spacing to the content, best use case when creating a lateral header to eleminate the FOUC effect.', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => '2',
	'choices'     => array(
		'1' => esc_attr__('On', 'realite-plugin'),
		'2' => esc_attr__('Off', 'realite-plugin')
	),
));

Kirki::add_field('grada_kirki', [
	'type'        => 'dimensions',
	'settings'    => 'body_offset_padding',
	'label'       => esc_html__('Offset Values', 'realite-plugin'),
	'description' => __('Enter the values of the offset, if you\'re using the menu on the left, add padding on the left side and so on. <br /><small>Note: Do not forget to enter the unit too.</small>', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => [
		'padding-left'  => '',
		'padding-right' => '',
	],
	'choices'     => [
		'labels' => [
			'padding-left'  => esc_html__('Left', 'realite-plugin'),
			'padding-right'  => esc_html__('Right', 'realite-plugin'),
		],
	],
	'active_callback' => array(
		array(
			'setting'  => 'body_offset',
			'operator' => '==',
			'value'    => '1'
		),
	)
]);

Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'body_offset_breakpoint',
	'label'       => esc_html__('Offset Breakpoint', 'realite-plugin'),
	'description' => __('Select from which device you want to remove the offset.', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => '1',
	'choices'     => array(
		'1' => esc_attr__('Tablet', 'realite-plugin'),
		'2' => esc_attr__('Mobile', 'realite-plugin')
	),
	'active_callback' => array(
		array(
			'setting'  => 'body_offset',
			'operator' => '==',
			'value'    => '1'
		),
	)
));

Kirki::add_field('grada_kirki', array(
	'type'        => 'select',
	'settings'    => 'theme_borders',
	'label'       => esc_html__('Theme Borders', 'realite-plugin'),
	'description' => esc_html__('Add borders all around the theme, you\'ll be able to specify the thickness and the color in the fields below.', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => '2',
	'choices'     => array(
		'1' => esc_attr__('On', 'realite-plugin'),
		'2' => esc_attr__('Off', 'realite-plugin')
	),
));

Kirki::add_field('grada_kirki', array(
	'type'        => 'slider',
	'settings'    => 'theme_borders_thickness',
	'label'       => esc_html__('Border Thickness', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => 16,
	'choices'     => [
		'min'  => 0,
		'max'  => 100,
		'step' => 1,
	],
	'active_callback' => array(
		array(
			'setting'  => 'theme_borders',
			'operator' => '==',
			'value'    => '1'
		),
	)
));

Kirki::add_field('grada_kirki', array(
	'type'        => 'color',
	'settings'    => 'theme_borders_color',
	'label'       => esc_html__('Border Color', 'realite-plugin'),
	'section'     => 'general_section',
	'default'     => '#FFFFFF',
	'active_callback' => array(
		array(
			'setting'  => 'theme_borders',
			'operator' => '==',
			'value'    => '1'
		),
	)
) );

Kirki::add_field('grada_kirki', array(
	'type'        => 'repeater',
	'settings'    => 'general_sidebars',
	'label'       => esc_attr__('Custom Sidebar', 'realite-plugin'),
	'description' => esc_html__('Create new sidebars and use them later via the page builder for different areas.', 'realite-plugin'),
	'section'     => 'general_section',
	'row_label' => array(
		'type' => 'text',
		'value' => esc_html__('Custom Sidebar', 'realite-plugin'),
	),
	'button_label' => esc_html__('Add new sidebar area', 'realite-plugin'),
	'default'      => '',
	'fields' => array(
		'sidebar_title' => array(
			'type'        => 'text',
			'label'       => esc_html__('Sidebar Title', 'realite-plugin'),
			'default'     => '',
		),
		'sidebar_description' => array(
			'type'        => 'text',
			'label'       => esc_html__('Sidebar Description', 'realite-plugin'),
			'default'     => '',
		),
	)
));

Kirki::add_field('grada_kirki', array(
	'type'        => 'repeater',
	'settings'    => 'general_image_sizes',
	'label'       => esc_attr__('Image Size', 'realite-plugin'),
	'description' => __('Create new image sizes, if you leave height blank it will be set to auto. <br /> <small>Note: Enter only the number without unit, it\'s represented in pixels.</small>', 'realite-plugin'),
	'section'     => 'general_section',
	'row_label' => array(
		'type' => 'text',
		'value' => esc_attr__('Image Size', 'realite-plugin'),
	),
	'button_label' => esc_attr__('Add new image size', 'realite-plugin'),
	'default'      => array(
		array(
			'image_size_width' => '560',
			'image_size_height' => '400'
		)
	),
	'fields' => array(
		'image_size_width' => array(
			'type'        => 'text',
			'label'       => esc_attr__('Width', 'realite-plugin'),
		),
		'image_size_height' => array(
			'type'        => 'text',
			'label'       => esc_attr__('Height', 'realite-plugin'),
		),
	)
));